@@ -8,7 +8,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -80,6 +80,8 @@ GetDowncastSwigType (SBMLConverter* con)
      else if (conName == "SBML Function Definition Converter")
        return SWIGTYPE_p_SBMLFunctionDefinitionConverter;
 
+#include "local-downcast-converters.cpp"	
+	   
 	return SWIGTYPE_p_SBMLConverter;
 }
 
@@ -295,6 +297,26 @@ GetDowncastSwigTypeForPackage (SBase* sb, const std::string &pkgName)
   return SWIGTYPE_p_SBase;
 }
 
+#ifndef LIBSBML_USE_LEGACY_MATH
+
+/**
+ * @return the most specific Swig type for the given ASTBasePlugin object.
+ */
+struct swig_type_info*
+GetDowncastSwigType (ASTBasePlugin* sbp)
+{
+  if (sbp == 0) return SWIGTYPE_p_ASTBasePlugin;
+
+  const std::string pkgName = sbp->getPackageName();
+	
+#include "local-downcast-astplugins.cpp"
+
+  return SWIGTYPE_p_ASTBasePlugin;
+}
+
+
+#endif // #ifndef LIBSBML_USE_LEGACY_MATH
+
 /* Compatibility bug fix for swig 2.0.7 and Python 3. 
  * See http://patch-tracker.debian.org/patch/series/view/swig2.0/2.0.7-3/pyint_fromsize_t.diff
  */
