@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -545,8 +545,7 @@ KineticLaw::addParameter (const Parameter* p)
       }
       else
       {
-        mLocalParameters.append(&lp);
-        return LIBSBML_OPERATION_SUCCESS;
+        return mLocalParameters.append(&lp);
       }
     }
   }
@@ -569,9 +568,7 @@ KineticLaw::addParameter (const Parameter* p)
   }
   else
   {
-    mParameters.append(p);
-
-    return LIBSBML_OPERATION_SUCCESS;
+    return mParameters.append(p);
   }
 }
 
@@ -594,9 +591,7 @@ KineticLaw::addLocalParameter (const LocalParameter* p)
   }
   else
   {
-    mLocalParameters.append(p);
-
-    return LIBSBML_OPERATION_SUCCESS;
+    return mLocalParameters.append(p);
   }
 }
 
@@ -911,6 +906,7 @@ KineticLaw::getDerivedUnitDefinition() const
 }
 
 
+/** @cond doxygenLibsbmlInternal */
 /*
  * Predicate returning @c true if 
  * the math expression of this KineticLaw contains
@@ -967,13 +963,16 @@ KineticLaw::containsUndeclaredUnits()
     return false;
   }
 }
+/** @endcond */
 
 
+/** @cond doxygenLibsbmlInternal */
 bool 
 KineticLaw::containsUndeclaredUnits() const
 {
   return const_cast<KineticLaw *> (this)->containsUndeclaredUnits();
 }
+/** @endcond */
 
 /**
  * Removes the nth Parameter object in the list of local parameters 
@@ -1028,14 +1027,14 @@ KineticLaw::setSBMLDocument (SBMLDocument* d)
 {
   SBase::setSBMLDocument(d);
 
-  if (getLevel() < 3)
-  {
+  //if (getLevel() < 3)
+  //{
   mParameters.setSBMLDocument(d);
-  }
-  else
-  {
+  //}
+  //else
+  //{
   mLocalParameters.setSBMLDocument(d);
-  }
+  //}
 }
 
 
@@ -1139,6 +1138,7 @@ int KineticLaw::removeFromParentAndDelete()
 void
 KineticLaw::renameSIdRefs(const std::string& oldid, const std::string& newid)
 {
+  SBase::renameSIdRefs(oldid, newid);
   //If the oldid is actually a local parameter, we should not rename it.
   if (getParameter(oldid) != NULL) return;
   if (getLocalParameter(oldid) != NULL) return;
@@ -1150,6 +1150,7 @@ KineticLaw::renameSIdRefs(const std::string& oldid, const std::string& newid)
 void 
 KineticLaw::renameUnitSIdRefs(const std::string& oldid, const std::string& newid)
 {
+  SBase::renameUnitSIdRefs(oldid, newid);
   if (isSetMath()) {
     mMath->renameUnitSIdRefs(oldid, newid);
   }
@@ -1229,10 +1230,14 @@ KineticLaw::writeElements (XMLOutputStream& stream) const
   SBase::writeElements(stream);
 
   if ( getLevel() > 1 && isSetMath() ) writeMathML(getMath(), stream, getSBMLNamespaces());
-  if ( getLevel() < 3 && getNumParameters() > 0 ) mParameters.write(stream);
-  if ( getLevel() > 2 && getNumLocalParameters() > 0 ) 
+  if ( getLevel() < 3 && getNumParameters() > 0 ) 
+  {
+    mParameters.write(stream);
+  }
+  else if ( getLevel() > 2 && getNumLocalParameters() > 0 ) 
+  {
     mLocalParameters.write(stream);
-
+  }
   //
   // (EXTENSION)
   //
@@ -1489,7 +1494,7 @@ KineticLaw::readL2Attributes (const XMLAttributes& attributes)
  * parents implementation of this method as well.
  */
 void
-KineticLaw::readL3Attributes (const XMLAttributes& attributes)
+KineticLaw::readL3Attributes (const XMLAttributes&)
 {
 }
 /** @endcond */
