@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -113,7 +113,7 @@ Parameter::Parameter (SBMLNamespaces * sbmlns) :
 
 
 /** @cond doxygenLibsbmlInternal */
-Parameter::Parameter (SBMLNamespaces * sbmlns, bool isLocal) :
+Parameter::Parameter (SBMLNamespaces * sbmlns, bool) :
    SBase      ( sbmlns   )
  , mId        ( ""       )
  , mName      ( ""       )
@@ -699,6 +699,7 @@ Parameter::hasRequiredAttributes() const
 void 
 Parameter::renameUnitSIdRefs(const std::string& oldid, const std::string& newid)
 {
+  SBase::renameUnitSIdRefs(oldid, newid);
   if (mUnits == oldid) mUnits= newid;
 }
 
@@ -955,7 +956,7 @@ Parameter::readL3Attributes (const XMLAttributes& attributes)
   if (!SyntaxChecker::isValidInternalUnitSId(mUnits))
   {
     logError(InvalidUnitIdSyntax, level, version, "The " + elplusid + 
-      " has a substanceUnits with a value of '" + mUnits 
+      " has a unit with a value of '" + mUnits 
       + "' which does not conform .");
   }
 
@@ -1411,7 +1412,7 @@ Parameter::inferUnitsFromKineticLaw(KineticLaw* kl,
     {
       if (rnId == m->getReaction(i)->getId())
       {
-        index = i;
+        index = (int)i;
         break;
       }
     }
@@ -1507,11 +1508,11 @@ ListOfParameters::get(unsigned int n) const
  */
 struct IdEqP : public unary_function<SBase*, bool>
 {
-  const string& id;
+  const string& mId;
 
-  IdEqP (const string& id) : id(id) { }
+  IdEqP (const string& id) : mId(id) { }
   bool operator() (SBase* sb) 
-       { return static_cast <Parameter *> (sb)->getId() == id; }
+       { return static_cast <Parameter *> (sb)->getId() == mId; }
 };
 /* return item by id */
 Parameter*
