@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -330,6 +330,7 @@ Reaction::getAllElements(ElementFilter *filter)
 void
 Reaction::renameSIdRefs(const std::string& oldid, const std::string& newid)
 {
+  SBase::renameSIdRefs(oldid, newid);
   if (mCompartment == oldid) {
     setCompartment(newid);
   }
@@ -792,12 +793,41 @@ Reaction::addReactant (const SpeciesReference* sr)
   }
   else
   {
-    mReactants.append(sr);
-
-    return LIBSBML_OPERATION_SUCCESS;
+    return mReactants.append(sr);
   }
 }
 
+int Reaction::addReactant(
+    const Species *species,
+    double stoichiometry,
+    const std::string &id,
+    bool constant)
+{
+  if (species == NULL)
+    return LIBSBML_INVALID_OBJECT;
+
+  if (!species->isSetId())
+    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
+
+  if (!id.empty() && getListOfReactants()->get(id) != NULL)
+    {
+      // an object with this id already exists
+      return LIBSBML_DUPLICATE_OBJECT_ID;
+    }
+
+  SpeciesReference* ref = createReactant();
+  if (!id.empty())
+    ref->setId(id);
+
+  if (stoichiometry == stoichiometry)
+    ref->setStoichiometry(stoichiometry);
+
+  ref->setSpecies(species->getId());
+  ref->setConstant(constant);
+
+  return LIBSBML_OPERATION_SUCCESS;
+}
+
 
 /*
  * Adds a copy of the given product (SpeciesReference) to this Reaction.
@@ -818,12 +848,42 @@ Reaction::addProduct (const SpeciesReference* sr)
   }
   else
   {
-    mProducts.append(sr);
-
-    return LIBSBML_OPERATION_SUCCESS;
+    return mProducts.append(sr);
   }
 }
 
+int
+Reaction::addProduct(
+    const Species *species,
+    double stoichiometry,
+    const std::string &id,
+    bool constant)
+{
+  if (species == NULL)
+    return LIBSBML_INVALID_OBJECT;
+
+  if (!species->isSetId())
+    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
+
+  if (!id.empty() && getListOfProducts()->get(id) != NULL)
+    {
+      // an object with this id already exists
+      return LIBSBML_DUPLICATE_OBJECT_ID;
+    }
+
+  SpeciesReference* ref = createProduct();
+  if (!id.empty())
+    ref->setId(id);
+
+  if (stoichiometry == stoichiometry)
+    ref->setStoichiometry(stoichiometry);
+
+  ref->setSpecies(species->getId());
+  ref->setConstant(constant);
+
+  return LIBSBML_OPERATION_SUCCESS;
+}
+
 
 /*
  * Adds a copy of the given modifier (ModifierSpeciesReference) to this
@@ -845,12 +905,36 @@ Reaction::addModifier (const ModifierSpeciesReference* msr)
   }
   else
   {
-    mModifiers.append(msr);
-
-    return LIBSBML_OPERATION_SUCCESS;
+    return mModifiers.append(msr);
   }
 }
 
+int
+Reaction::addModifier(
+    const Species *species,
+    const std::string &id)
+{
+  if (species == NULL)
+    return LIBSBML_INVALID_OBJECT;
+
+  if (!species->isSetId())
+    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
+
+  if (!id.empty() && getListOfModifiers()->get(id) != NULL)
+  {
+    // an object with this id already exists
+    return LIBSBML_DUPLICATE_OBJECT_ID;
+  }
+
+  ModifierSpeciesReference* ref = createModifier();
+  if (!id.empty())
+    ref->setId(id);
+
+  ref->setSpecies(species->getId());
+
+  return LIBSBML_OPERATION_SUCCESS;
+}
+
 
 /*
  * Creates a new SpeciesReference, adds it to this Reaction's list of
@@ -1618,7 +1702,7 @@ Reaction::readL2Attributes (const XMLAttributes& attributes)
   //
   if (version == 2) 
     mSBOTerm = SBO::readTerm(attributes, this->getErrorLog(), level, version,
-				getLine(), getColumn());
+        getLine(), getColumn());
 
 }
 /** @endcond */
@@ -2282,6 +2366,20 @@ Reaction_addReactant (Reaction_t *r, const SpeciesReference_t *sr)
 }
 
 
+LIBSBML_EXTERN
+int
+Reaction_addReactantBySpecies (Reaction_t *r, const Species_t *s, 
+                               double stoichiometry, const char *id,
+                               int constant)
+{
+  if (r != NULL)
+    return r->addReactant( static_cast<const Species*>(s), stoichiometry, id, 
+                            constant);
+  else
+    return LIBSBML_INVALID_OBJECT;
+}
+
+
 LIBSBML_EXTERN
 int
 Reaction_addProduct (Reaction_t *r, const SpeciesReference_t *sr)
@@ -2293,6 +2391,20 @@ Reaction_addProduct (Reaction_t *r, const SpeciesReference_t *sr)
 }
 
 
+LIBSBML_EXTERN
+int
+Reaction_addProductBySpecies (Reaction_t *r, const Species_t *s, 
+                               double stoichiometry, const char *id,
+                               int constant)
+{
+  if (r != NULL)
+    return r->addProduct( static_cast<const Species*>(s), stoichiometry, id, 
+                            constant);
+  else
+    return LIBSBML_INVALID_OBJECT;
+}
+
+
 LIBSBML_EXTERN
 int
 Reaction_addModifier (Reaction_t *r, const SpeciesReference_t *msr)
@@ -2313,6 +2425,18 @@ Reaction_addModifier (Reaction_t *r, const SpeciesReference_t *msr)
 }
 
 
+LIBSBML_EXTERN
+int
+Reaction_addModifierBySpecies (Reaction_t *r, const Species_t *s, 
+                               const char *id)
+{
+  if (r != NULL)
+    return r->addModifier( static_cast<const Species*>(s), id);
+  else
+    return LIBSBML_INVALID_OBJECT;
+}
+
+
 LIBSBML_EXTERN
 SpeciesReference_t *
 Reaction_createReactant (Reaction_t *r)
