@@ -43,6 +43,7 @@
 
 #include <sbml/validator/SBMLInternalValidator.h>
 #include <sbml/validator/StrictUnitConsistencyValidator.h>
+#include <sbml/validator/UnitConsistencyValidator.h>
 
 #include <sbml/Model.h>
 #include <sbml/SBMLErrorLog.h>
@@ -501,6 +502,22 @@ SBMLDocument::setLevelAndVersion (unsigned int level, unsigned int version,
     return false;
 }
 
+/** @cond doxygenLibsbmlInternal */
+
+/* 
+* function to set level to 0 on a doc that was just been created to read in to
+* the SBMLReader will only do this if the file is found to be invalid
+* this will allow for testing for an SBMLDocument without
+* relying on it having a model to be valid 
+* (in L3V2 a missing model will be valid) 
+*/
+void 
+SBMLDocument::setInvalidLevel()
+{
+  mLevel = 0;
+}
+
+/** @endcond */
 
 /** @cond doxygenLibsbmlInternal */
 void 
@@ -888,6 +905,12 @@ SBMLDocument::checkInternalConsistency()
   return numErrors;
 }
 
+unsigned int
+getLevelVersionSeverity(unsigned int errorId, unsigned int level, unsigned int version)
+{
+  return SBMLError(errorId, level, version).getSeverity();
+}
+
 /*
  * Performs a set of semantic consistency checks on the document to establish
  * whether it is compatible with L1 and can be converted.  Query
@@ -896,9 +919,47 @@ SBMLDocument::checkInternalConsistency()
  * @return the number of failed checks (errors) encountered.
  */
 unsigned int
-SBMLDocument::checkL1Compatibility ()
+SBMLDocument::checkL1Compatibility (bool inConversion)
 {
-  return mInternalValidator->checkL1Compatibility();
+  unsigned int nerrors =  mInternalValidator->checkL1Compatibility();
+  unsigned int unit_errors = 0;
+
+  if (inConversion == false)
+  {
+    UnitConsistencyValidator unit_validator;
+    unit_validator.init();
+    unit_errors = unit_validator.validate(*this);
+    if (unit_errors > 0)
+    {
+      // need to check whether these are what would be warnings
+      // and only log the error if there would be a units error
+      bool logUnitError = false;
+      std::list<SBMLError> errors = unit_validator.getFailures();
+      std::list<SBMLError>::iterator it = errors.begin();
+
+      while(!logUnitError && it != errors.end())
+      {
+        SBMLError err = (SBMLError)(*it);
+        unsigned int l2v1_sev = getLevelVersionSeverity(err.getErrorId(), 1, 2);
+        if (l2v1_sev == LIBSBML_SEV_ERROR)
+        {
+          logUnitError = true;
+        }
+        it++;
+      }
+      if (logUnitError)
+      {
+        getErrorLog()->logError(StrictUnitsRequiredInL1, getLevel(), getVersion());
+        unit_errors = 1;
+      }
+      else
+      {
+        unit_errors = 0;
+      }
+    }
+  }
+
+  return nerrors + unit_errors;
 }
 
 
@@ -910,9 +971,47 @@ SBMLDocument::checkL1Compatibility ()
  * @return the number of failed checks (errors) encountered.
  */
 unsigned int
-SBMLDocument::checkL2v1Compatibility ()
+SBMLDocument::checkL2v1Compatibility (bool inConversion)
 {
-  return mInternalValidator->checkL2v1Compatibility();
+  unsigned int nerrors = mInternalValidator->checkL2v1Compatibility();
+  unsigned int unit_errors = 0;
+
+  if (inConversion == false)
+  {
+    UnitConsistencyValidator unit_validator;
+    unit_validator.init();
+    unit_errors = unit_validator.validate(*this);
+    if (unit_errors > 0)
+    {
+      // need to check whether these are what would be warnings
+      // and only log the error if there would be a units error
+      bool logUnitError = false;
+      std::list<SBMLError> errors = unit_validator.getFailures();
+      std::list<SBMLError>::iterator it = errors.begin();
+
+      while(!logUnitError && it != errors.end())
+      {
+        SBMLError err = (SBMLError)(*it);
+        unsigned int l2v1_sev = getLevelVersionSeverity(err.getErrorId(), 2, 1);
+        if (l2v1_sev == LIBSBML_SEV_ERROR)
+        {
+          logUnitError = true;
+        }
+        it++;
+      }
+      if (logUnitError)
+      {
+        getErrorLog()->logError(StrictUnitsRequiredInL2v1, getLevel(), getVersion());
+        unit_errors = 1;
+      }
+      else
+      {
+        unit_errors = 0;
+      }
+    }
+  }
+
+  return nerrors + unit_errors;
 }
 
 
@@ -924,9 +1023,47 @@ SBMLDocument::checkL2v1Compatibility ()
  * @return the number of failed checks (errors) encountered.
  */
 unsigned int
-SBMLDocument::checkL2v2Compatibility ()
+SBMLDocument::checkL2v2Compatibility (bool inConversion)
 {
-  return mInternalValidator->checkL2v2Compatibility();
+  unsigned int nerrors =  mInternalValidator->checkL2v2Compatibility();
+  unsigned int unit_errors = 0;
+
+  if (inConversion == false)
+  {
+    UnitConsistencyValidator unit_validator;
+    unit_validator.init();
+    unit_errors = unit_validator.validate(*this);
+    if (unit_errors > 0)
+    {
+      // need to check whether these are what would be warnings
+      // and only log the error if there would be a units error
+      bool logUnitError = false;
+      std::list<SBMLError> errors = unit_validator.getFailures();
+      std::list<SBMLError>::iterator it = errors.begin();
+
+      while(!logUnitError && it != errors.end())
+      {
+        SBMLError err = (SBMLError)(*it);
+        unsigned int l2v1_sev = getLevelVersionSeverity(err.getErrorId(), 1, 2);
+        if (l2v1_sev == LIBSBML_SEV_ERROR)
+        {
+          logUnitError = true;
+        }
+        it++;
+      }
+      if (logUnitError)
+      {
+        getErrorLog()->logError(StrictUnitsRequiredInL2v2, getLevel(), getVersion());
+        unit_errors = 1;
+      }
+      else
+      {
+        unit_errors = 0;
+      }
+    }
+  }
+
+  return nerrors + unit_errors;
 }
 
 
@@ -938,9 +1075,47 @@ SBMLDocument::checkL2v2Compatibility ()
  * @return the number of failed checks (errors) encountered.
  */
 unsigned int
-SBMLDocument::checkL2v3Compatibility ()
+SBMLDocument::checkL2v3Compatibility (bool inConversion)
 {
-  return mInternalValidator->checkL2v3Compatibility();
+  unsigned int nerrors =  mInternalValidator->checkL2v3Compatibility();
+  unsigned int unit_errors = 0;
+
+  if (inConversion == false)
+  {
+    UnitConsistencyValidator unit_validator;
+    unit_validator.init();
+    unit_errors = unit_validator.validate(*this);
+    if (unit_errors > 0)
+    {
+      // need to check whether these are what would be warnings
+      // and only log the error if there would be a units error
+      bool logUnitError = false;
+      std::list<SBMLError> errors = unit_validator.getFailures();
+      std::list<SBMLError>::iterator it = errors.begin();
+
+      while(!logUnitError && it != errors.end())
+      {
+        SBMLError err = (SBMLError)(*it);
+        unsigned int l2v1_sev = getLevelVersionSeverity(err.getErrorId(), 1, 2);
+        if (l2v1_sev == LIBSBML_SEV_ERROR)
+        {
+          logUnitError = true;
+        }
+        it++;
+      }
+      if (logUnitError)
+      {
+        getErrorLog()->logError(StrictUnitsRequiredInL2v3, getLevel(), getVersion());
+        unit_errors = 1;
+      }
+      else
+      {
+        unit_errors = 0;
+      }
+    }
+  }
+
+  return nerrors + unit_errors;
 }
 
 
@@ -958,6 +1133,20 @@ SBMLDocument::checkL2v4Compatibility ()
 }
 
 
+/*
+ * Performs a set of semantic consistency checks on the document to establish
+ * whether it is compatible with L2v4 and can be converted.  Query
+ * the results by calling getNumErrors() and getError().
+ *
+ * @return the number of failed checks (errors) encountered.
+ */
+unsigned int
+SBMLDocument::checkL2v5Compatibility ()
+{
+  return mInternalValidator->checkL2v5Compatibility();
+}
+
+
 /*
  * Performs a set of semantic consistency checks on the document to establish
  * whether it is compatible with L2v1 and can be converted.  Query
@@ -1292,9 +1481,7 @@ SBMLDocument::addUnknownPackageRequired(const std::string& pkgURI,
 {
   std::string value = (flag) ? "true" : "false";
 
-  mRequiredAttrOfUnknownPkg.add("required", value, pkgURI, prefix);
-
-  return LIBSBML_OPERATION_SUCCESS;
+  return mRequiredAttrOfUnknownPkg.add("required", value, pkgURI, prefix);
 }
 /** @endcond */
 
@@ -2285,6 +2472,14 @@ SBMLDocument_checkL2v4Compatibility (SBMLDocument_t *d)
 }
 
 
+LIBSBML_EXTERN
+unsigned int 
+SBMLDocument_checkL2v5Compatibility (SBMLDocument_t *d)
+{
+  return (d != NULL) ? d->checkL2v5Compatibility() : SBML_INT_MAX;
+}
+
+
 LIBSBML_EXTERN
 unsigned int 
 SBMLDocument_checkL3v1Compatibility (SBMLDocument_t *d)
