@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -390,7 +390,7 @@ SBMLNamespaces::addPackageNamespace(const std::string &pkgName, unsigned int pkg
     const std::string prefix = (pkgPrefix.empty()) ? pkgName : pkgPrefix;
     if (!uri.empty() && mNamespaces != NULL)
     {
-      mNamespaces->add(uri,prefix);
+      return mNamespaces->add(uri,prefix);
     }
     else
     {
@@ -849,11 +849,11 @@ SBMLNamespaces_getSupportedNamespaces(int *length)
    const List* supported = SBMLNamespaces::getSupportedNamespaces();
   
    *length = (int) supported->getSize();
-  SBMLNamespaces_t ** result = (SBMLNamespaces_t**)malloc(sizeof(SBMLNamespaces_t*)*(*length));
-  memset(result, 0, sizeof(SBMLNamespaces_t*)*(*length));
+  SBMLNamespaces_t ** result = (SBMLNamespaces_t**)malloc(sizeof(SBMLNamespaces_t*)*((unsigned long)*length));
+  memset(result, 0, sizeof(SBMLNamespaces_t*)*((unsigned long)*length));
   for (int i = 0; i < *length; i++)
   {
-    result[i] = ((SBMLNamespaces*)supported->get(i))->clone();
+    result[i] = ((SBMLNamespaces*)supported->get((unsigned int)i))->clone();
   }
   SBMLNamespaces::freeSBMLNamespaces(const_cast<List*>(supported));
   return result;
