@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -536,11 +536,30 @@ UnitDefinition::addUnit (const Unit* u)
   {
     return returnValue;
   }
+  else if (u == NULL)
+  {
+    return LIBSBML_OPERATION_FAILED;
+  }
+  else if (u->hasRequiredAttributes() == false)
+  {
+    return LIBSBML_INVALID_OBJECT;
+  }
+  else if (getLevel() != u->getLevel())
+  {
+    return LIBSBML_LEVEL_MISMATCH;
+  }
+  else if (getVersion() != u->getVersion())
+  {
+    return LIBSBML_VERSION_MISMATCH;
+  }
+  else if (matchesRequiredSBMLNamespacesForAddition(static_cast<const
+    SBase*>(u)) == false)
+  {
+    return LIBSBML_NAMESPACES_MISMATCH;
+  }
   else
   {
-    mUnits.append(u);
-
-    return LIBSBML_OPERATION_SUCCESS;
+    return mUnits.append(u);
   }
 }
 
@@ -875,7 +894,7 @@ UnitDefinition::reorder(UnitDefinition *ud)
 
   for (n = 0; n < numUnits; n++)
   {
-    Unit * unit = (Unit *)(units->get(n));
+    unit = (Unit *)(units->get(n));
     int value = unit->getKind();
     indexArray[n] = value;
     initialIndexArray[n] = value;
@@ -1761,11 +1780,11 @@ ListOfUnitDefinitions::get(unsigned int n) const
  */
 struct IdEqUD : public unary_function<SBase*, bool>
 {
-  const string& id;
+  const string& mId;
 
-  IdEqUD (const string& id) : id(id) { }
+  IdEqUD (const string& id) : mId(id) { }
   bool operator() (SBase* sb) 
-       { return static_cast <UnitDefinition *> (sb)->getId() == id; }
+       { return static_cast <UnitDefinition *> (sb)->getId() == mId; }
 };
 
 
