@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -285,7 +285,7 @@ Submodel::unsetModelRef ()
 
 
 int
-Submodel::setSubstanceConversionFactor (const std::string& substanceConversionFactor)
+Submodel::setSubstanceConversionFactor (const std::string&)
 {
   return LIBSBML_INVALID_ATTRIBUTE_VALUE;
 }
@@ -546,20 +546,20 @@ Submodel::readAttributes (const XMLAttributes& attributes,
     static_cast<ListOfSubmodels*>(getParentSBMLObject())->size() < 2)
   {
     unsigned int numErrs = getErrorLog()->getNumErrors();
-    for (int n = numErrs-1; n >= 0; n--)      
+    for (int n = (int)numErrs-1; n >= 0; n--)
     {
-      if (getErrorLog()->getError(n)->getErrorId() == UnknownPackageAttribute)
+      if (getErrorLog()->getError((unsigned int)n)->getErrorId() == UnknownPackageAttribute)
       {
         const std::string details = 
-          getErrorLog()->getError(n)->getMessage();
+          getErrorLog()->getError((unsigned int)n)->getMessage();
         getErrorLog()->remove(UnknownPackageAttribute);
         getErrorLog()->logPackageError("comp", CompLOSubmodelsAllowedAttributes,
           getPackageVersion(), sbmlLevel, sbmlVersion, details);
       } 
-      else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
+      else if (getErrorLog()->getError((unsigned int)n)->getErrorId() == UnknownCoreAttribute)
       {
         const std::string details = 
-          getErrorLog()->getError(n)->getMessage();
+          getErrorLog()->getError((unsigned int)n)->getMessage();
         getErrorLog()->remove(UnknownCoreAttribute);
         getErrorLog()->logPackageError("comp", CompLOSubmodelsAllowedAttributes,
           getPackageVersion(), sbmlLevel, sbmlVersion, details);
@@ -574,20 +574,20 @@ Submodel::readAttributes (const XMLAttributes& attributes,
   if (getErrorLog() != NULL)
   {
     unsigned int numErrs = getErrorLog()->getNumErrors();
-    for (int n = numErrs-1; n >= 0; n--)      
+    for (int n = (int)numErrs-1; n >= 0; n--)
     {
-      if (getErrorLog()->getError(n)->getErrorId() == UnknownPackageAttribute)
+      if (getErrorLog()->getError((unsigned int)n)->getErrorId() == UnknownPackageAttribute)
       {
         const std::string details = 
-          getErrorLog()->getError(n)->getMessage();
+          getErrorLog()->getError((unsigned int)n)->getMessage();
         getErrorLog()->remove(UnknownPackageAttribute);
         getErrorLog()->logPackageError("comp", CompSubmodelAllowedAttributes,
           getPackageVersion(), sbmlLevel, sbmlVersion, details);
       } 
-      else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
+      else if (getErrorLog()->getError((unsigned int)n)->getErrorId() == UnknownCoreAttribute)
       {
         const std::string details = 
-          getErrorLog()->getError(n)->getMessage();
+          getErrorLog()->getError((unsigned int)n)->getMessage();
         getErrorLog()->remove(UnknownCoreAttribute);
         getErrorLog()->logPackageError("comp", CompSubmodelAllowedCoreAttributes,
           getPackageVersion(), sbmlLevel, sbmlVersion, details);
@@ -1399,7 +1399,7 @@ Submodel::removeProcessingCallback(int index)
 {
   if (index < 0 || index >= getNumProcessingCallbacks()) return;
 
-  ModelProcessingCallbackData* cbdata = mProcessingCBs[index];
+  ModelProcessingCallbackData* cbdata = mProcessingCBs[(size_t)index];
   mProcessingCBs.erase(mProcessingCBs.begin() + index, mProcessingCBs.begin() + 1 + index);
   delete cbdata;
 }
@@ -1411,7 +1411,7 @@ Submodel::removeProcessingCallback(ModelProcessingCallback cb)
 {
   for(int i = getNumProcessingCallbacks() -1; i >= 0; --i)
   {
-    ModelProcessingCallbackData* cbdata = mProcessingCBs[i];
+    ModelProcessingCallbackData* cbdata = mProcessingCBs[(size_t)i];
     if (cbdata->cb == cb)
     {
       removeProcessingCallback(i);
@@ -1491,7 +1491,7 @@ Submodel_getModelRef(Submodel_t * s)
 
 LIBSBML_EXTERN
 char *
-Submodel_getSubstanceConversionFactor(Submodel_t * s)
+Submodel_getSubstanceConversionFactor(Submodel_t * )
 {
   return NULL;
 }
@@ -1545,7 +1545,7 @@ Submodel_isSetModelRef(Submodel_t * s)
 
 LIBSBML_EXTERN
 int
-Submodel_isSetSubstanceConversionFactor(Submodel_t * s)
+Submodel_isSetSubstanceConversionFactor(Submodel_t * )
 {
   return 0;
 }
@@ -1593,7 +1593,7 @@ Submodel_setModelRef(Submodel_t * s, const char * modelRef)
 
 LIBSBML_EXTERN
 int
-Submodel_setSubstanceConversionFactor(Submodel_t * s, const char * substanceConversionFactor)
+Submodel_setSubstanceConversionFactor(Submodel_t * , const char * )
 {
   return LIBSBML_INVALID_ATTRIBUTE_VALUE;
 }
@@ -1641,7 +1641,7 @@ Submodel_unsetModelRef(Submodel_t * s)
 
 LIBSBML_EXTERN
 int
-Submodel_unsetSubstanceConversionFactor(Submodel_t * s)
+Submodel_unsetSubstanceConversionFactor(Submodel_t * )
 {
   return LIBSBML_OPERATION_FAILED;
 }
@@ -1735,6 +1735,14 @@ Submodel_hasRequiredAttributes(Submodel_t * s)
 }
 
 
+LIBSBML_EXTERN
+int
+Submodel_hasRequiredElements(Submodel_t * s)
+{
+  return (s != NULL) ? static_cast<int>(s->hasRequiredElements()) : 0;
+}
+
+
 LIBSBML_EXTERN
 Submodel_t *
 ListOfSubmodels_getById(ListOf_t * lo, const char * sid)
