@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -357,7 +357,7 @@ CompFlatteningConverter::performConversion()
 
   if (getPerformValidation() == true)
   {
-    int result = validateOriginalDocument();
+    result = validateOriginalDocument();
     if (result != LIBSBML_OPERATION_SUCCESS) 
     {
       return result;
@@ -401,7 +401,9 @@ CompFlatteningConverter::performConversion()
 
   if (getPerformValidation() == true)
   {
-    int result = validateFlatDocument(flatmodel, 
+    flatmodel->populateAllElementIdList();
+    flatmodel->populateAllElementMetaIdList();
+    result = validateFlatDocument(flatmodel,
                     modelPlugin->getPackageVersion(), modelPlugin->getLevel(), 
                     modelPlugin->getVersion());
     if (result != LIBSBML_OPERATION_SUCCESS)
@@ -470,13 +472,13 @@ CompFlatteningConverter::reconstructDocument(Model * flatmodel,
                               (mDocument->getPlugin("comp"));
       }
 
-      for (i = docPlug->getNumModelDefinitions() - 1; i >= 0; i--)
+      for (i = (int)docPlug->getNumModelDefinitions() - 1; i >= 0; i--)
       {
-        delete docPlug->removeModelDefinition(i);
+        delete docPlug->removeModelDefinition((unsigned int)i);
       }
-      for (i = docPlug->getNumExternalModelDefinitions() - 1; i >= 0; i--)
+      for (i = (int)docPlug->getNumExternalModelDefinitions() - 1; i >= 0; i--)
       {
-        delete docPlug->removeExternalModelDefinition(i);
+        delete docPlug->removeExternalModelDefinition((unsigned int)i);
       }
 
     }
@@ -973,6 +975,32 @@ CompFlatteningConverter::getPackagesToStrip() const
 }
 /** @endcond */
 
+// simple callback disabling packages on child documents
+int DisablePackageOnChildDocuments(Model* m, SBMLErrorLog *, void* userdata)
+{
+  if (m == NULL) return LIBSBML_OPERATION_FAILED;
+
+  IdList *pkgsToStrip = static_cast<IdList*>(userdata);
+
+  XMLNamespaces *ns = m->getSBMLNamespaces()->getNamespaces();
+  for (int i = 0; i < ns->getLength(); i++)
+  {
+    std::string nsURI = ns->getURI(i);
+    std::string package = ns->getPrefix(i);
+    if (package.empty() == true)
+    {
+      continue;
+    }
+    else if (pkgsToStrip->contains(package) == true)
+    {
+      m->enablePackageInternal(nsURI, package, false);
+    }
+  }
+
+  return LIBSBML_OPERATION_SUCCESS;
+}
+
+
 
 /** @cond doxygenLibsbmlInternal */
 void
@@ -988,7 +1016,9 @@ CompFlatteningConverter::stripUnflattenablePackages()
       continue;
     }
 
-    bool flattenable = getFlattenableStatus(package);
+    // need to be enabled in order to flatten so need to check both
+    bool flattenable = getFlattenableStatus(package) &&
+      SBMLExtensionRegistry::getInstance().isEnabled(package);
 
     // if we can flatten we dont need to strip
     if (flattenable == true)
@@ -1042,6 +1072,7 @@ CompFlatteningConverter::stripUnflattenablePackages()
       mDocument->getErrorLog()->logPackageError("comp", errorId, 
         mDocument->getPlugin("comp")->getPackageVersion(), 
         mDocument->getLevel(), mDocument->getVersion(), message);
+      mPkgsToStrip->append(package);
     }
     else if (getAbortForRequired() == true)
     {
@@ -1053,38 +1084,18 @@ CompFlatteningConverter::stripUnflattenablePackages()
         mDocument->getErrorLog()->logPackageError("comp", errorId, 
           mDocument->getPlugin("comp")->getPackageVersion(), 
           mDocument->getLevel(), mDocument->getVersion(), message);
+        mPkgsToStrip->append(package);
       }
     }
 
+    // setup callback that will disable the packages on submodels
+    Submodel::addProcessingCallback(&DisablePackageOnChildDocuments, mPkgsToStrip);
+
+
   }
 }
 /** @endcond */
 
-// simple callback disabling packages on child documents
-int DisablePackageOnChildDocuments(Model* m, SBMLErrorLog *, void* userdata)
-{
-  if (m == NULL) return LIBSBML_OPERATION_FAILED;
-
-  IdList *pkgsToStrip = static_cast<IdList*>(userdata);
-
-  XMLNamespaces *ns = m->getSBMLNamespaces()->getNamespaces();
-  for (int i = 0; i < ns->getLength(); i++)
-  {
-    std::string nsURI = ns->getURI(i);
-    std::string package = ns->getPrefix(i);
-    if (package.empty() == true)
-    {
-      continue;
-    }
-    else if (pkgsToStrip->contains(package) == true)
-    {
-      m->enablePackageInternal(nsURI, package, false);
-    }
-  }
-
-  return LIBSBML_OPERATION_SUCCESS;
-}
-
 /** @cond doxygenLibsbmlInternal */
 int
 CompFlatteningConverter::stripPackages()
@@ -1117,7 +1128,7 @@ CompFlatteningConverter::stripPackages()
   unsigned int count = 0;
   for (unsigned int i = 0; i < num; i++)
   {
-    if (mDocument->isPackageEnabled(mPkgsToStrip->at(i)) == false)
+    if (mDocument->isPackageEnabled(mPkgsToStrip->at((int)i)) == false)
     {
       count++;
     }
