@@ -421,12 +421,16 @@ FbcModelPlugin::parseAnnotation(SBase *parentObject, XMLNode *pAnnotation)
 
 
 /** @cond doxygenLibsbmlInternal */
+#ifndef ANNOATION
+bool
+FbcModelPlugin::readOtherXML (SBase* /*parentObject*/, XMLInputStream& /*stream*/)
+{
+  return false;
+}
+#else
 bool
 FbcModelPlugin::readOtherXML (SBase* parentObject, XMLInputStream& stream)
 {
-#ifndef ANNOATION
-  return false;
-#else
   bool readAnnotationFromStream = false;
   const string& name = stream.peek().getName();
   
@@ -522,14 +526,17 @@ FbcModelPlugin::readOtherXML (SBase* parentObject, XMLInputStream& stream)
   }
   
   return readAnnotationFromStream;
-#endif
 }
+#endif
 /** @endcond */
 
 
 /*
  * Checks if this plugin object has all the required elements.
  */
+  //According to the specs for both FBC v1 and v2, the model plugin has no 
+  // required children!
+/*
 bool
 FbcModelPlugin::hasRequiredElements () const
 {
@@ -540,10 +547,9 @@ FbcModelPlugin::hasRequiredElements () const
     allPresent = false;    
   }
 
-
   return allPresent; 
 }
-
+*/
 
   /** @cond doxygenLibsbmlInternal */
 
@@ -823,10 +829,8 @@ int
   }
   else
   {
-    mBounds.append(bound);
+    return mBounds.append(bound);
   }
-
-  return LIBSBML_OPERATION_SUCCESS;
 }
 
 
@@ -1073,10 +1077,13 @@ FbcModelPlugin::addObjective(const Objective* o)
   {
     return LIBSBML_VERSION_MISMATCH;
   }
+  else if (getPackageVersion() != o->getPackageVersion())
+  {
+    return LIBSBML_PKG_VERSION_MISMATCH;
+  }
   else
   {
-    mObjectives.append(o);
-    return LIBSBML_OPERATION_SUCCESS;
+    return mObjectives.append(o);
   }
 }
 
@@ -1253,10 +1260,13 @@ FbcModelPlugin::addGeneProduct(const GeneProduct* gp)
   {
     return LIBSBML_VERSION_MISMATCH;
   }
+  else if (getPackageVersion() != gp->getPackageVersion())
+  {
+    return LIBSBML_PKG_VERSION_MISMATCH;
+  }
   else
   {
-    mGeneProducts.append(gp);
-    return LIBSBML_OPERATION_SUCCESS;
+    return mGeneProducts.append(gp);
   }
 }
 
@@ -1478,10 +1488,8 @@ int
   }
   else
   {
-    mAssociations.append(association);
+    return mAssociations.append(association);
   }
-
-  return LIBSBML_OPERATION_SUCCESS;
 }
 
 /*
@@ -1776,6 +1784,49 @@ FbcModelPlugin_setActiveObjectiveId(SBasePlugin_t * fbc, const char * activeId)
     ? static_cast<FbcModelPlugin *>(fbc)->setActiveObjectiveId(activeId) 
     : LIBSBML_INVALID_OBJECT;
 }
+
+
+LIBSBML_EXTERN
+int
+FbcModelPlugin_addGeneProduct(SBasePlugin_t * fbc, GeneProduct_t * fb)
+{
+  return (fbc != NULL) ? static_cast<FbcModelPlugin*>(fbc)->addGeneProduct(fb)
+    : LIBSBML_INVALID_OBJECT;
+}
+
+
+LIBSBML_EXTERN
+GeneProduct_t *
+FbcModelPlugin_getGeneProduct(SBasePlugin_t * fbc, unsigned int n)
+{
+  return (fbc != NULL) ? static_cast<FbcModelPlugin*>(fbc)->getGeneProduct(n)
+    : NULL;
+}
+
+
+LIBSBML_EXTERN
+unsigned int
+FbcModelPlugin_getNumGeneProducts(SBasePlugin_t * fbc)
+{
+  return (fbc != NULL) ? static_cast<FbcModelPlugin*>(fbc)->getNumGeneProducts()
+    : SBML_INT_MAX;
+}
+
+LIBSBML_EXTERN
+int
+FbcModelPlugin_getStrict(SBasePlugin_t * fmp)
+{
+  return (int)(((FbcModelPlugin*)(fmp))->getStrict());
+}
+
+
+LIBSBML_EXTERN
+int
+FbcModelPlugin_setStrict(SBasePlugin_t * fmp, int strict)
+{
+  return ((FbcModelPlugin*)(fmp))->setStrict((bool)(strict));
+}
+
 /** @endcond */
 
 
