@@ -1,13 +1,13 @@
 /**
- * @file:   FbcAssociation.cpp
- * @brief:  Implementation of the FbcAssociation class
- * @author: SBMLTeam
+ * @file   FbcAssociation.cpp
+ * @brief  Implementation of the FbcAssociation class
+ * @author SBMLTeam
  *
  * <!--------------------------------------------------------------------------
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -288,7 +288,22 @@ FbcAssociation* toAssociation(const ASTNode* node, FbcModelPlugin* plugin)
 
   if (node->getType() == AST_NAME)
   {
-    GeneProduct* prod = plugin->getGeneProduct(node->getName());
+    std::string name = node->getName();
+    replaceAllSubStrings(name, "__DOT__", ".");
+    replaceAllSubStrings(name, "__ONE__", "1");
+    replaceAllSubStrings(name, "__TWO__", "2");
+    replaceAllSubStrings(name, "__THREE__", "3");
+    replaceAllSubStrings(name, "__FOUR__", "4");
+    replaceAllSubStrings(name, "__FIVE__", "5");
+    replaceAllSubStrings(name, "__SIX__", "6");
+    replaceAllSubStrings(name, "__SEVEN__", "7");
+    replaceAllSubStrings(name, "__EIGHT__", "8");
+    replaceAllSubStrings(name, "__NINE__", "9");
+    replaceAllSubStrings(name, "__ZERO__", "0");
+
+    GeneProduct* prod = plugin->getGeneProductByLabel(node->getName());
+    if (prod == NULL)
+        prod = plugin->getGeneProductByLabel(name);
     string id;
     if (prod == NULL)
     {
@@ -303,18 +318,6 @@ FbcAssociation* toAssociation(const ASTNode* node, FbcModelPlugin* plugin)
         id = str.str();
       }
       prod->setId(id);
-      std::string name = node->getName();
-      replaceAllSubStrings(name, "__DOT__", ".");
-      replaceAllSubStrings(name, "__ONE__", "1");
-      replaceAllSubStrings(name, "__TWO__", "2");
-      replaceAllSubStrings(name, "__THREE__", "3");
-      replaceAllSubStrings(name, "__FOUR__", "4");
-      replaceAllSubStrings(name, "__FIVE__", "5");
-      replaceAllSubStrings(name, "__SIX__", "6");
-      replaceAllSubStrings(name, "__SEVEN__", "7");
-      replaceAllSubStrings(name, "__EIGHT__", "8");
-      replaceAllSubStrings(name, "__NINE__", "9");
-      replaceAllSubStrings(name, "__ZERO__", "0");
       prod->setLabel(name);
     }
     else
@@ -451,20 +454,20 @@ FbcAssociation::readAttributes (const XMLAttributes& attributes,
       static_cast<ListOfFbcAssociations*>(getParentSBMLObject())->size() < 2)
   {
     numErrs = getErrorLog()->getNumErrors();
-    for (int n = numErrs-1; n >= 0; n--)
+    for (int n = (int)numErrs-1; n >= 0; n--)
     {
-      if (getErrorLog()->getError(n)->getErrorId() == UnknownPackageAttribute)
+      if (getErrorLog()->getError((unsigned int)n)->getErrorId() == UnknownPackageAttribute)
       {
         const std::string details =
-              getErrorLog()->getError(n)->getMessage();
+              getErrorLog()->getError((unsigned int)n)->getMessage();
         getErrorLog()->remove(UnknownPackageAttribute);
         getErrorLog()->logPackageError("fbc", FbcUnknown,
                   getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
       }
-      else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
+      else if (getErrorLog()->getError((unsigned int)n)->getErrorId() == UnknownCoreAttribute)
       {
         const std::string details =
-                   getErrorLog()->getError(n)->getMessage();
+                   getErrorLog()->getError((unsigned int)n)->getMessage();
         getErrorLog()->remove(UnknownCoreAttribute);
         getErrorLog()->logPackageError("fbc", FbcUnknown,
                   getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
@@ -488,20 +491,20 @@ FbcAssociation::readAttributes (const XMLAttributes& attributes,
     {
       coreErr = FbcOrAllowedCoreAttributes;
     }
-    for (int n = numErrs-1; n >= 0; n--)
+    for (int n = (int)numErrs-1; n >= 0; n--)
     {
-      if (getErrorLog()->getError(n)->getErrorId() == UnknownPackageAttribute)
+      if (getErrorLog()->getError((unsigned int)n)->getErrorId() == UnknownPackageAttribute)
       {
         const std::string details =
-                          getErrorLog()->getError(n)->getMessage();
+                          getErrorLog()->getError((unsigned int)n)->getMessage();
         getErrorLog()->remove(UnknownPackageAttribute);
         getErrorLog()->logPackageError("fbc", pkgErr,
                        getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
       }
-      else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
+      else if (getErrorLog()->getError((unsigned int)n)->getErrorId() == UnknownCoreAttribute)
       {
         const std::string details =
-                          getErrorLog()->getError(n)->getMessage();
+                          getErrorLog()->getError((unsigned int)n)->getMessage();
         getErrorLog()->remove(UnknownCoreAttribute);
         getErrorLog()->logPackageError("fbc", coreErr,
                        getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
@@ -607,7 +610,7 @@ ListOfFbcAssociations::get(const std::string& sid) const
 }
 
 
-/**
+/*
  * Adds a copy the given "FbcAssociation" to this ListOfFbcAssociations.
  *
  * @param fa; the FbcAssociation object to add
@@ -644,13 +647,12 @@ ListOfFbcAssociations::addFbcAssociation(const FbcAssociation* fa)
   }
   else
   {
-  append(fa);
-    return LIBSBML_OPERATION_SUCCESS;
+    return append(fa);
   }
 }
 
 
-/**
+/*
  * Get the number of FbcAssociation objects in this ListOfFbcAssociations.
  *
  * @return the number of FbcAssociation objects in this ListOfFbcAssociations
@@ -661,7 +663,8 @@ ListOfFbcAssociations::getNumFbcAssociations() const
   return size();
 }
 
-/**
+
+/*
  * Creates a new FbcAnd object, adds it to this ListOfFbcAssociations
  * and and returns the FbcAnd object created. 
  *
@@ -697,7 +700,8 @@ ListOfFbcAssociations::createAnd()
   return fa;
 }
 
-/**
+
+/*
  * Creates a new FbcOr object, adds it to this ListOfFbcAssociations
  * or and returns the FbcOr object created. 
  *
@@ -733,7 +737,8 @@ ListOfFbcAssociations::createOr()
   return fo;
 }
 
-/**
+
+/*
  * Creates a new GeneProductRef object, adds it to this ListOfFbcAssociations
  * geneProductRef and returns the GeneProductRef object created. 
  *
@@ -908,6 +913,13 @@ ListOfFbcAssociations::writeXMLNS(XMLOutputStream& stream) const
 
   /** @endcond doxygenLibsbmlInternal */
 
+bool
+ListOfFbcAssociations::isValidTypeForList(SBase * item)
+{
+    int code = item->getTypeCode();
+    return code == getItemTypeCode() || code == SBML_FBC_AND || code == SBML_FBC_OR || code == SBML_FBC_GENEPRODUCTREF ;
+}
+
 
 LIBSBML_EXTERN
 FbcAssociation_t *
@@ -978,6 +990,26 @@ ListOfFbcAssociations_removeById(ListOf_t * lo, const char * sid)
 }
 
 
+LIBSBML_EXTERN
+char *
+FbcAssociation_toInfix(const FbcAssociation_t * fa)
+{
+  return (fa != NULL) ? safe_strdup(fa->toInfix().c_str()) : NULL;
+}
+
+
+FbcAssociation_t*
+FbcAssociation_parseFbcInfixAssociation(const char * infix, SBasePlugin_t* plugin)
+{
+  if (infix == NULL || plugin == NULL)
+  {
+    return NULL;
+  }
+
+  return FbcAssociation::parseFbcInfixAssociation(infix, static_cast<FbcModelPlugin*>(plugin));
+}
+
+
 
 
 LIBSBML_CPP_NAMESPACE_END
