@@ -286,11 +286,12 @@ public:
   /** @endcond doxygenLibsbmlInternal */
 
 
-  virtual void setElementName(const std::string& name);
 
 
 protected:
 
+    virtual void setElementName(const std::string& name);
+
   /** @cond doxygenLibsbmlInternal */
 
   /**
@@ -321,7 +322,7 @@ protected:
 
   /** @endcond doxygenLibsbmlInternal */
 
-
+  friend class GeneProductAssociation;
 
 };
 
@@ -706,6 +707,7 @@ int
 FbcAssociation_hasRequiredAttributes(const FbcAssociation_t * fa);
 
 
+
 LIBSBML_EXTERN
 FbcAssociation_t *
 ListOfFbcAssociations_getById(ListOf_t * lo, const char * sid);
@@ -716,7 +718,13 @@ FbcAssociation_t *
 ListOfFbcAssociations_removeById(ListOf_t * lo, const char * sid);
 
 
+LIBSBML_EXTERN
+char *
+FbcAssociation_toInfix(const FbcAssociation_t * fa);
 
+LIBSBML_EXTERN
+FbcAssociation_t*
+FbcAssociation_parseFbcInfixAssociation(const char * infix, SBasePlugin_t* plugin);
 
 END_C_DECLS
 LIBSBML_CPP_NAMESPACE_END
