@@ -241,14 +241,17 @@ FbcOr::addAssociation(const FbcAssociation* fa)
   {
     return LIBSBML_VERSION_MISMATCH;
   }
+  else if (getPackageVersion() != fa->getPackageVersion())
+  {
+    return LIBSBML_PKG_VERSION_MISMATCH;
+  }
   else if (matchesRequiredSBMLNamespacesForAddition(static_cast<const SBase *>(fa)) == false)
   {
     return LIBSBML_NAMESPACES_MISMATCH;
   }
   else
   {
-    mAssociations.append(fa);
-    return LIBSBML_OPERATION_SUCCESS;
+    return mAssociations.append(fa);
   }
 }
 
@@ -448,9 +451,7 @@ FbcOr::hasRequiredAttributes () const
 bool
 FbcOr::hasRequiredElements () const
 {
-  bool allPresent = FbcAssociation::hasRequiredElements();
-
-  return allPresent;
+  return getNumAssociations() >= 2;
 }
 
 
