@@ -1,13 +1,13 @@
 /**
- * @file:   FluxObjective.cpp
- * @brief:  Implementation of the FluxObjective class
- * @author: SBMLTeam
+ * @file   FluxObjective.cpp
+ * @brief  Implementation of the FluxObjective class
+ * @author SBMLTeam
  *
  *<!---------------------------------------------------------------------------
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -341,6 +341,7 @@ FluxObjective::unsetCoefficient()
 void
 FluxObjective::renameSIdRefs(const std::string& oldid, const std::string& newid)
 {
+  SBase::renameSIdRefs(oldid, newid);
   if (isSetReaction() == true && mReaction == oldid)
   {
     setReaction(newid);
@@ -489,20 +490,20 @@ FluxObjective::readAttributes (const XMLAttributes& attributes,
     static_cast<ListOfFluxObjectives*>(getParentSBMLObject())->size() < 2)
   {
     unsigned int numErrs = getErrorLog()->getNumErrors();
-    for (int n = numErrs - 1; n >= 0; n--)
+    for (int n = (int)numErrs - 1; n >= 0; n--)
     {
-      if (getErrorLog()->getError(n)->getErrorId() == UnknownPackageAttribute)
+      if (getErrorLog()->getError((unsigned int)n)->getErrorId() == UnknownPackageAttribute)
       {
         const std::string details =
-          getErrorLog()->getError(n)->getMessage();
+          getErrorLog()->getError((unsigned int)n)->getMessage();
         getErrorLog()->remove(UnknownPackageAttribute);
         getErrorLog()->logPackageError("fbc", FbcObjectiveLOFluxObjAllowedAttribs,
           getPackageVersion(), sbmlLevel, sbmlVersion, details);
       }
-      else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
+      else if (getErrorLog()->getError((unsigned int)n)->getErrorId() == UnknownCoreAttribute)
       {
         const std::string details =
-          getErrorLog()->getError(n)->getMessage();
+          getErrorLog()->getError((unsigned int)n)->getMessage();
         getErrorLog()->remove(UnknownCoreAttribute);
         getErrorLog()->logPackageError("fbc", FbcObjectiveLOFluxObjAllowedAttribs,
           getPackageVersion(), sbmlLevel, sbmlVersion, details);
@@ -516,20 +517,20 @@ FluxObjective::readAttributes (const XMLAttributes& attributes,
   if (getErrorLog() != NULL)
   {
     unsigned int numErrs = getErrorLog()->getNumErrors();
-    for (int n = numErrs - 1; n >= 0; n--)
+    for (int n = (int)numErrs - 1; n >= 0; n--)
     {
-      if (getErrorLog()->getError(n)->getErrorId() == UnknownPackageAttribute)
+      if (getErrorLog()->getError((unsigned int)n)->getErrorId() == UnknownPackageAttribute)
       {
         const std::string details =
-          getErrorLog()->getError(n)->getMessage();
+          getErrorLog()->getError((unsigned int)n)->getMessage();
         getErrorLog()->remove(UnknownPackageAttribute);
         getErrorLog()->logPackageError("fbc", FbcFluxObjectRequiredAttributes,
           getPackageVersion(), sbmlLevel, sbmlVersion, details);
       }
-      else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
+      else if (getErrorLog()->getError((unsigned int)n)->getErrorId() == UnknownCoreAttribute)
       {
         const std::string details =
-          getErrorLog()->getError(n)->getMessage();
+          getErrorLog()->getError((unsigned int)n)->getMessage();
         getErrorLog()->remove(UnknownCoreAttribute);
         getErrorLog()->logPackageError("fbc", FbcFluxObjectAllowedL3Attributes,
           getPackageVersion(), sbmlLevel, sbmlVersion, details);
@@ -730,7 +731,7 @@ ListOfFluxObjectives::get(const std::string& sid) const
 }
 
 
-/**
+/*
  * Adds a copy the given "FluxObjective" to this ListOfFluxObjectives.
  *
  * @param fo; the FluxObjective object to add
@@ -767,13 +768,12 @@ ListOfFluxObjectives::addFluxObjective(const FluxObjective* fo)
   }
   else
   {
-  append(fo);
-    return LIBSBML_OPERATION_SUCCESS;
+    return append(fo);
   }
 }
 
 
-/**
+/*
  * Get the number of FluxObjective objects in this ListOfFluxObjectives.
  *
  * @return the number of FluxObjective objects in this ListOfFluxObjectives
@@ -784,7 +784,8 @@ ListOfFluxObjectives::getNumFluxObjectives() const
   return size();
 }
 
-/**
+
+/*
  * Creates a new FluxObjective object, adds it to this ListOfFluxObjectives
  * FluxObjective and returns the FluxObjective object created. 
  *
