@@ -1,13 +1,13 @@
 /**
- * @file:   GeneProduct.cpp
- * @brief:  Implementation of the GeneProduct class
- * @author: SBMLTeam
+ * @file   GeneProduct.cpp
+ * @brief  Implementation of the GeneProduct class
+ * @author SBMLTeam
  *
  * <!--------------------------------------------------------------------------
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -341,6 +341,7 @@ GeneProduct::unsetAssociatedSpecies()
 void
 GeneProduct::renameSIdRefs(const std::string& oldid, const std::string& newid)
 {
+  SBase::renameSIdRefs(oldid, newid);
   if (isSetAssociatedSpecies() == true && mAssociatedSpecies == oldid)
   {
     setAssociatedSpecies(newid);
@@ -493,22 +494,22 @@ GeneProduct::readAttributes (const XMLAttributes& attributes,
       static_cast<ListOfGeneProducts*>(getParentSBMLObject())->size() < 2)
   {
     numErrs = getErrorLog()->getNumErrors();
-    for (int n = numErrs-1; n >= 0; n--)
+    for (int n = (int)numErrs-1; n >= 0; n--)
     {
-      if (getErrorLog()->getError(n)->getErrorId() == UnknownPackageAttribute)
+      if (getErrorLog()->getError((unsigned int)n)->getErrorId() == UnknownPackageAttribute)
       {
         const std::string details =
-              getErrorLog()->getError(n)->getMessage();
+              getErrorLog()->getError((unsigned int)n)->getMessage();
         getErrorLog()->remove(UnknownPackageAttribute);
         getErrorLog()->logPackageError("fbc", FbcGeneProductAllowedAttributes,
                   getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
       }
-      else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
+      else if (getErrorLog()->getError((unsigned int)n)->getErrorId() == UnknownCoreAttribute)
       {
         const std::string details =
-                   getErrorLog()->getError(n)->getMessage();
+                   getErrorLog()->getError((unsigned int)n)->getMessage();
         getErrorLog()->remove(UnknownCoreAttribute);
-        getErrorLog()->logPackageError("fbc", FbcGeneProcuctAllowedCoreAttributes,
+        getErrorLog()->logPackageError("fbc", FbcGeneProductAllowedCoreAttributes,
                   getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
       }
     }
@@ -520,22 +521,22 @@ GeneProduct::readAttributes (const XMLAttributes& attributes,
   if (getErrorLog() != NULL)
   {
     numErrs = getErrorLog()->getNumErrors();
-    for (int n = numErrs-1; n >= 0; n--)
+    for (int n = (int)numErrs-1; n >= 0; n--)
     {
-      if (getErrorLog()->getError(n)->getErrorId() == UnknownPackageAttribute)
+      if (getErrorLog()->getError((unsigned int)n)->getErrorId() == UnknownPackageAttribute)
       {
         const std::string details =
-                          getErrorLog()->getError(n)->getMessage();
+                          getErrorLog()->getError((unsigned int)n)->getMessage();
         getErrorLog()->remove(UnknownPackageAttribute);
         getErrorLog()->logPackageError("fbc", FbcGeneProductAllowedAttributes,
                        getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
       }
-      else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
+      else if (getErrorLog()->getError((unsigned int)n)->getErrorId() == UnknownCoreAttribute)
       {
         const std::string details =
-                          getErrorLog()->getError(n)->getMessage();
+                          getErrorLog()->getError((unsigned int)n)->getMessage();
         getErrorLog()->remove(UnknownCoreAttribute);
-        getErrorLog()->logPackageError("fbc", FbcGeneProcuctAllowedCoreAttributes,
+        getErrorLog()->logPackageError("fbc", FbcGeneProductAllowedCoreAttributes,
                        getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
       }
     }
@@ -772,13 +773,12 @@ ListOfGeneProducts::addGeneProduct(const GeneProduct* gp)
   }
   else
   {
-	append(gp);
-    return LIBSBML_OPERATION_SUCCESS;
+	return append(gp);
   }
 }
 
 
-/**
+/*
  * Get the number of GeneProduct objects in this ListOfGeneProducts.
  *
  * @return the number of GeneProduct objects in this ListOfGeneProducts
@@ -789,7 +789,8 @@ ListOfGeneProducts::getNumGeneProducts() const
 	return size();
 }
 
-/**
+
+/*
  * Creates a new GeneProduct object, adds it to this ListOfGeneProducts
  * GeneProduct and returns the GeneProduct object created. 
  *
