@@ -1,13 +1,13 @@
 /**
- * @file:   Objective.cpp
- * @brief:  Implementation of the Objective class
- * @author: SBMLTeam
+ * @file   Objective.cpp
+ * @brief  Implementation of the Objective class
+ * @author SBMLTeam
  *
  *<!---------------------------------------------------------------------------
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -440,8 +440,7 @@ Objective::addFluxObjective(const FluxObjective* fo)
   }
   else
   {
-    mFluxObjectives.append(fo);
-    return LIBSBML_OPERATION_SUCCESS;
+    return mFluxObjectives.append(fo);
   }
 }
 
@@ -554,9 +553,7 @@ Objective::hasRequiredAttributes () const
 bool
 Objective::hasRequiredElements () const
 {
-  bool allPresent = true;
-
-  return allPresent;
+  return getNumFluxObjectives() > 0;
 }
 
 
@@ -571,6 +568,7 @@ Objective::getIsSetListOfFluxObjectives() const
 /** @endcond */
 
 
+/** @cond doxygenLibsbmlInternal */
 /*
  * write contained elements
  */
@@ -585,6 +583,7 @@ Objective::writeElements (XMLOutputStream& stream) const
 
   SBase::writeExtensionElements(stream);
 }
+/** @endcond */
 
 
   /** @endcond doxygenLibsbmlInternal */
@@ -733,20 +732,20 @@ Objective::readAttributes (const XMLAttributes& attributes,
     static_cast<ListOfObjectives*>(getParentSBMLObject())->size() < 2)
   {
     unsigned int numErrs = getErrorLog()->getNumErrors();
-    for (int n = numErrs-1; n >= 0; n--)      
+    for (int n = (int)numErrs-1; n >= 0; n--)
     {
-      if (getErrorLog()->getError(n)->getErrorId() == UnknownPackageAttribute)
+      if (getErrorLog()->getError((unsigned int)n)->getErrorId() == UnknownPackageAttribute)
       {
         const std::string details = 
-          getErrorLog()->getError(n)->getMessage();
+          getErrorLog()->getError((unsigned int)n)->getMessage();
         getErrorLog()->remove(UnknownPackageAttribute);
         getErrorLog()->logPackageError("fbc", FbcLOObjectivesAllowedAttributes,
           getPackageVersion(), sbmlLevel, sbmlVersion, details);
       } 
-      else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
+      else if (getErrorLog()->getError((unsigned int)n)->getErrorId() == UnknownCoreAttribute)
       {
         const std::string details = 
-          getErrorLog()->getError(n)->getMessage();
+          getErrorLog()->getError((unsigned int)n)->getMessage();
         getErrorLog()->remove(UnknownCoreAttribute);
         getErrorLog()->logPackageError("fbc", FbcLOObjectivesAllowedAttributes,
           getPackageVersion(), sbmlLevel, sbmlVersion, details);
@@ -760,20 +759,20 @@ Objective::readAttributes (const XMLAttributes& attributes,
   if (getErrorLog() != NULL)
   {
     unsigned int numErrs = getErrorLog()->getNumErrors();
-    for (int n = numErrs-1; n >= 0; n--)      
+    for (int n = (int)numErrs-1; n >= 0; n--)
     {
-      if (getErrorLog()->getError(n)->getErrorId() == UnknownPackageAttribute)
+      if (getErrorLog()->getError((unsigned int)n)->getErrorId() == UnknownPackageAttribute)
       {
         const std::string details = 
-          getErrorLog()->getError(n)->getMessage();
+          getErrorLog()->getError((unsigned int)n)->getMessage();
         getErrorLog()->remove(UnknownPackageAttribute);
         getErrorLog()->logPackageError("fbc", FbcObjectiveRequiredAttributes,
           getPackageVersion(), sbmlLevel, sbmlVersion, details);
       } 
-      else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
+      else if (getErrorLog()->getError((unsigned int)n)->getErrorId() == UnknownCoreAttribute)
       {
         const std::string details = 
-          getErrorLog()->getError(n)->getMessage();
+          getErrorLog()->getError((unsigned int)n)->getMessage();
         getErrorLog()->remove(UnknownCoreAttribute);
         getErrorLog()->logPackageError("fbc", FbcObjectiveAllowedL3Attributes,
           getPackageVersion(), sbmlLevel, sbmlVersion, details);
@@ -978,7 +977,7 @@ ListOfObjectives::get(const std::string& sid) const
 }
 
 
-/**
+/*
  * Adds a copy the given "Objective" to this ListOfObjectives.
  *
  * @param o; the Objective object to add
@@ -1015,13 +1014,12 @@ ListOfObjectives::addObjective(const Objective* o)
   }
   else
   {
-  append(o);
-    return LIBSBML_OPERATION_SUCCESS;
+    return append(o);
   }
 }
 
 
-/**
+/*
  * Get the number of Objective objects in this ListOfObjectives.
  *
  * @return the number of Objective objects in this ListOfObjectives
@@ -1032,7 +1030,7 @@ ListOfObjectives::getNumObjectives() const
   return size();
 }
 
-/**
+/*
  * Creates a new Objective object, adds it to this ListOfObjectives
  * Objective and returns the Objective object created. 
  *
