@@ -426,8 +426,7 @@ Group::addMember(const Member* m)
   }
   else
   {
-    mMembers.append(m);
-    return LIBSBML_OPERATION_SUCCESS;
+    return mMembers.append(m);
   }
 }
 
@@ -530,20 +529,6 @@ Group::hasRequiredAttributes() const
 }
 
 
-/*
- * Predicate returning @c true if all the required elements for this Group
- * object have been set.
- */
-bool
-Group::hasRequiredElements() const
-{
-  bool allPresent = true;
-
-  return allPresent;
-}
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -650,14 +635,13 @@ Group::getElementBySId(const std::string& id)
     return NULL;
   }
 
-  if (mMembers.isSetId()) {
-    if (id == mMembers.getId()) {
-      return &mMembers;
-    }
-  }
-
   SBase* obj = NULL;
 
+  if (mMembers.getId() == id)
+  {
+    return &mMembers;
+  }
+
   obj = mMembers.getElementBySId(id);
 
   if (obj != NULL)
@@ -797,15 +781,16 @@ Group::readAttributes(const XMLAttributes& attributes,
       {
         const std::string details = log->getError(n)->getMessage();
         log->remove(UnknownPackageAttribute);
-        log->logPackageError("groups", GroupsGroupAllowedAttributes, pkgVersion, level,
-          version, details);
+        log->logPackageError("groups", GroupsGroupAllowedAttributes,
+          pkgVersion, level, version, details);
       }
       else if (log->getError(n)->getErrorId() == UnknownCoreAttribute)
       {
         const std::string details = log->getError(n)->getMessage();
         log->remove(UnknownCoreAttribute);
-        log->logPackageError("groups", GroupsModelLOGroupsAllowedCoreAttributes, pkgVersion, level,
-          version, details);
+        log->logPackageError("groups",
+          GroupsModelLOGroupsAllowedCoreAttributes, pkgVersion, level, version,
+            details);
       }
     }
   }
@@ -845,8 +830,10 @@ Group::readAttributes(const XMLAttributes& attributes,
     }
     else if (SyntaxChecker::isValidSBMLSId(mId) == false)
     {
-      logError(InvalidIdSyntax, level, version, "The id '" + mId + "' does not "
-        "conform to the syntax.");
+      log->logPackageError("groups", GroupsIdSyntaxRule,
+        pkgVersion, level, version, "The id on the <" 
+        + getElementName() + "> is '" + mId + "', which does not conform to the syntax.", 
+        getLine(), getColumn());
     }
   }
 
