@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -92,7 +92,7 @@ Dimensions::Dimensions (LayoutPkgNamespaces* layoutns, double width, double heig
   , mW(width)
   , mH(height)
   , mD(depth)
-  , mDExplicitlySet (true)
+  , mDExplicitlySet (depth != 0.0)
 {
   //
   // set the element namespace of this object
@@ -397,20 +397,20 @@ void Dimensions::readAttributes (const XMLAttributes& attributes,
   if (getErrorLog() != NULL)
     {
       numErrs = getErrorLog()->getNumErrors();
-      for (int n = numErrs-1; n >= 0; n--)
+      for (int n = (int)numErrs-1; n >= 0; n--)
       {
-        if (getErrorLog()->getError(n)->getErrorId() == UnknownPackageAttribute)
+        if (getErrorLog()->getError((unsigned int)n)->getErrorId() == UnknownPackageAttribute)
         {
           const std::string details =
-            getErrorLog()->getError(n)->getMessage();
+            getErrorLog()->getError((unsigned int)n)->getMessage();
           getErrorLog()->remove(UnknownPackageAttribute);
           getErrorLog()->logPackageError("layout", LayoutDimsAllowedAttributes,
             getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
         }
-        else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
+        else if (getErrorLog()->getError((unsigned int)n)->getErrorId() == UnknownCoreAttribute)
         {
           const std::string details =
-            getErrorLog()->getError(n)->getMessage();
+            getErrorLog()->getError((unsigned int)n)->getMessage();
           getErrorLog()->remove(UnknownCoreAttribute);
           getErrorLog()->logPackageError("layout", 
             LayoutDimsAllowedCoreAttributes,
@@ -551,7 +551,7 @@ void Dimensions::writeAttributes (XMLOutputStream& stream) const
   //
   // (TODO) default value should be allowd in package of Level 3?
   //
-  if(this->mD!=0.0)
+  if(this->mD!=0.0 || (getLevel() > 2 && mDExplicitlySet))
   {
     stream.writeAttribute("depth", getPrefix(), mD);
   }
