@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -387,14 +387,14 @@ public:
    * Adds a new reference glyph to the list.
    */
    
-  void addReferenceGlyph (const ReferenceGlyph* glyph);
+  int addReferenceGlyph (const ReferenceGlyph* glyph);
        
 
   /**
    * Adds a new subglyph to the list.
    */
    
-  void addSubGlyph (const GraphicalObject* glyph);
+  int addSubGlyph (const GraphicalObject* glyph);
 
   /**
    * Returns the number of reference glyph objects.
@@ -566,6 +566,7 @@ public:
   virtual int getTypeCode () const;
 
 
+  /** @cond doxygenLibsbmlInternal */
   /**
    * Accepts the given SBMLVisitor.
    *
@@ -574,6 +575,7 @@ public:
    * sibling object (if available).
    */
   virtual bool accept (SBMLVisitor& v) const;
+  /** @endcond */
    
    
    /**
