@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -1130,59 +1130,174 @@ Layout::getAdditionalGraphicalObject (const std::string& id)
 /*
  * Adds a new compartment glyph.
  */
-void
+int
 Layout::addCompartmentGlyph (const CompartmentGlyph* glyph)
 {
-  this->mCompartmentGlyphs.append(glyph);
+  if (!glyph)
+  {
+    return LIBSBML_OPERATION_FAILED;
+  }    
+  else if (!(glyph->hasRequiredElements() && glyph->hasRequiredAttributes()))
+  {
+    return LIBSBML_INVALID_OBJECT;
+  }
+  else if (getLevel() != glyph->getLevel())
+  {
+    return LIBSBML_LEVEL_MISMATCH;
+  }
+  else if (getVersion() != glyph->getVersion())
+  {
+    return LIBSBML_VERSION_MISMATCH;
+  }
+  else if (getPackageVersion() != glyph->getPackageVersion())
+  {
+    return LIBSBML_PKG_VERSION_MISMATCH;
+  }
+  else
+  {
+    return mCompartmentGlyphs.append(glyph);
+  }
 }
 
 
 /*
  * Adds a new species glyph.
  */
-void
+int
 Layout::addSpeciesGlyph (const SpeciesGlyph* glyph)
 {
-  this->mSpeciesGlyphs.append(glyph);
+  if (!glyph)
+  {
+    return LIBSBML_OPERATION_FAILED;
+  }    
+  else if (!(glyph->hasRequiredElements() && glyph->hasRequiredAttributes()))
+  {
+    return LIBSBML_INVALID_OBJECT;
+  }
+  else if (getLevel() != glyph->getLevel())
+  {
+    return LIBSBML_LEVEL_MISMATCH;
+  }
+  else if (getVersion() != glyph->getVersion())
+  {
+    return LIBSBML_VERSION_MISMATCH;
+  }
+  else if (getPackageVersion() != glyph->getPackageVersion())
+  {
+    return LIBSBML_PKG_VERSION_MISMATCH;
+  }
+  else
+  {
+    return mSpeciesGlyphs.append(glyph);
+  }
 }
 
 
 /*
  * Adds a new reaction glyph.
  */
-void
+int
 Layout::addReactionGlyph (const ReactionGlyph* glyph)
 {
-  this->mReactionGlyphs.append(glyph);
+  if (!glyph)
+  {
+    return LIBSBML_OPERATION_FAILED;
+  }    
+  else if (!(glyph->hasRequiredElements() && glyph->hasRequiredAttributes()))
+  {
+    return LIBSBML_INVALID_OBJECT;
+  }
+  else if (getLevel() != glyph->getLevel())
+  {
+    return LIBSBML_LEVEL_MISMATCH;
+  }
+  else if (getVersion() != glyph->getVersion())
+  {
+    return LIBSBML_VERSION_MISMATCH;
+  }
+  else if (getPackageVersion() != glyph->getPackageVersion())
+  {
+    return LIBSBML_PKG_VERSION_MISMATCH;
+  }
+  else
+  {
+    return mReactionGlyphs.append(glyph);
+  }
 }
 
 
 /*
  * Adds a new text glyph.
  */
-void
+int
 Layout::addTextGlyph (const TextGlyph* glyph)
 {
-  this->mTextGlyphs.append(glyph);
+  if (!glyph)
+  {
+    return LIBSBML_OPERATION_FAILED;
+  }    
+  else if (!(glyph->hasRequiredElements() && glyph->hasRequiredAttributes()))
+  {
+    return LIBSBML_INVALID_OBJECT;
+  }
+  else if (getLevel() != glyph->getLevel())
+  {
+    return LIBSBML_LEVEL_MISMATCH;
+  }
+  else if (getVersion() != glyph->getVersion())
+  {
+    return LIBSBML_VERSION_MISMATCH;
+  }
+  else if (getPackageVersion() != glyph->getPackageVersion())
+  {
+    return LIBSBML_PKG_VERSION_MISMATCH;
+  }
+  else
+  {
+    return mTextGlyphs.append(glyph);
+  }
 }
 
 
 /*
  * Adds a new additional graphical object glyph.
  */
-void
+int
 Layout::addAdditionalGraphicalObject (const GraphicalObject* glyph)
 {
-  this->mAdditionalGraphicalObjects.append(glyph);
+  if (!glyph)
+  {
+    return LIBSBML_OPERATION_FAILED;
+  }    
+  else if (!(glyph->hasRequiredElements() && glyph->hasRequiredAttributes()))
+  {
+    return LIBSBML_INVALID_OBJECT;
+  }
+  else if (getLevel() != glyph->getLevel())
+  {
+    return LIBSBML_LEVEL_MISMATCH;
+  }
+  else if (getVersion() != glyph->getVersion())
+  {
+    return LIBSBML_VERSION_MISMATCH;
+  }
+  else if (getPackageVersion() != glyph->getPackageVersion())
+  {
+    return LIBSBML_PKG_VERSION_MISMATCH;
+  }
+  else
+  {
+    return mAdditionalGraphicalObjects.append(glyph);
+  }
 }
 
 /*
  * Adds a new general glyph.
  */
-void
+int
 Layout::addGeneralGlyph (const GeneralGlyph* glyph)
 {
-  addAdditionalGraphicalObject(glyph);
+  return addAdditionalGraphicalObject(glyph);
 }
 
 
@@ -1355,7 +1470,7 @@ Layout::createAdditionalGraphicalObject ()
 SpeciesReferenceGlyph* 
 Layout::createSpeciesReferenceGlyph ()
 {
-  int size = this->mReactionGlyphs.size();
+  unsigned int size = this->mReactionGlyphs.size();
   if (size == 0) return NULL;
 
   ReactionGlyph* r =dynamic_cast<ReactionGlyph*> (this->getReactionGlyph(size - 1));
@@ -1372,7 +1487,7 @@ Layout::createSpeciesReferenceGlyph ()
 LineSegment* 
 Layout::createLineSegment()
 {
-  int size = this->mReactionGlyphs.size();
+  unsigned int size = this->mReactionGlyphs.size();
   if (size == 0) return NULL;
 
   LineSegment*   ls = NULL;
@@ -1402,7 +1517,7 @@ Layout::createLineSegment()
 CubicBezier* 
 Layout::createCubicBezier ()
 {
-  int size = this->mReactionGlyphs.size();
+  unsigned int size = this->mReactionGlyphs.size();
   if (size == 0) return NULL;
 
   CubicBezier*   cb = NULL;
@@ -1538,21 +1653,21 @@ Layout::readAttributes (const XMLAttributes& attributes,
     static_cast<ListOfLayouts*>(getParentSBMLObject())->size() < 2)
   {
     numErrs = getErrorLog()->getNumErrors();
-    for (int n = numErrs-1; n >= 0; n--)
+    for (int n = (int)numErrs-1; n >= 0; n--)
     {
-      if (getErrorLog()->getError(n)->getErrorId() == UnknownPackageAttribute)
+      if (getErrorLog()->getError((unsigned int)n)->getErrorId() == UnknownPackageAttribute)
       {
         const std::string details =
-          getErrorLog()->getError(n)->getMessage();
+          getErrorLog()->getError((unsigned int)n)->getMessage();
         getErrorLog()->remove(UnknownPackageAttribute);
         getErrorLog()->logPackageError("layout", 
           LayoutLOLayoutsAllowedAttributes,
           getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
       }
-      else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
+      else if (getErrorLog()->getError((unsigned int)n)->getErrorId() == UnknownCoreAttribute)
       {
         const std::string details =
-          getErrorLog()->getError(n)->getMessage();
+          getErrorLog()->getError((unsigned int)n)->getMessage();
         getErrorLog()->remove(UnknownCoreAttribute);
         getErrorLog()->logPackageError("layout", 
           LayoutLOLayoutsAllowedAttributes,
@@ -1567,20 +1682,20 @@ Layout::readAttributes (const XMLAttributes& attributes,
   if (getErrorLog() != NULL)
   {
     numErrs = getErrorLog()->getNumErrors();
-    for (int n = numErrs-1; n >= 0; n--)
+    for (int n = (int)numErrs-1; n >= 0; n--)
     {
-      if (getErrorLog()->getError(n)->getErrorId() == UnknownPackageAttribute)
+      if (getErrorLog()->getError((unsigned int)n)->getErrorId() == UnknownPackageAttribute)
       {
         const std::string details =
-          getErrorLog()->getError(n)->getMessage();
+          getErrorLog()->getError((unsigned int)n)->getMessage();
         getErrorLog()->remove(UnknownPackageAttribute);
         getErrorLog()->logPackageError("layout", LayoutLayoutAllowedAttributes,
           getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
       }
-      else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
+      else if (getErrorLog()->getError((unsigned int)n)->getErrorId() == UnknownCoreAttribute)
       {
         const std::string details =
-          getErrorLog()->getError(n)->getMessage();
+          getErrorLog()->getError((unsigned int)n)->getMessage();
         getErrorLog()->remove(UnknownCoreAttribute);
         getErrorLog()->logPackageError("layout", LayoutLayoutAllowedCoreAttributes,
           getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
@@ -1634,7 +1749,7 @@ Layout::writeAttributes (XMLOutputStream& stream) const
 
   if (isSetName())
   {
-    stream.writeAttribute("name", getPrefix(), mId);
+    stream.writeAttribute("name", getPrefix(), mName);
   }
 
   //
