@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -1114,36 +1114,36 @@ public:
    * Adds a new compartment glyph.
    */
   
-  void addCompartmentGlyph (const CompartmentGlyph* glyph);
+  int addCompartmentGlyph (const CompartmentGlyph* glyph);
 
   /**
    * Adds a new species glyph.
    */
   
-  void addSpeciesGlyph (const SpeciesGlyph* glyph);
+  int addSpeciesGlyph (const SpeciesGlyph* glyph);
 
   /**
    * Adds a new reaction glyph.
    */
   
-  void addReactionGlyph (const ReactionGlyph* glyph);
+  int addReactionGlyph (const ReactionGlyph* glyph);
 
   /**
    * Adds a new text glyph.
    */
   
-  void addTextGlyph (const TextGlyph* glyph);
+  int addTextGlyph (const TextGlyph* glyph);
 
   /**
    * Adds a new additional graphical object glyph.
    */
   
-  void addAdditionalGraphicalObject (const GraphicalObject* glyph);
+  int addAdditionalGraphicalObject (const GraphicalObject* glyph);
 
   /**
    * Adds a new general glyph.
    */
-  void addGeneralGlyph (const GeneralGlyph* glyph);
+  int addGeneralGlyph (const GeneralGlyph* glyph);
 
 
   /**
@@ -1398,6 +1398,7 @@ public:
   virtual int getTypeCode () const;
 
 
+  /** @cond doxygenLibsbmlInternal */
   /**
    * Accepts the given SBMLVisitor.
    *
@@ -1406,6 +1407,7 @@ public:
    * sibling object (if available).
    */
   virtual bool accept (SBMLVisitor& v) const;
+  /** @endcond */
    
 
    /**
