@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -352,7 +352,7 @@ public:
    * Adds a new species reference glyph to the list.
    */
    
-  void addSpeciesReferenceGlyph (const SpeciesReferenceGlyph* glyph);
+  int addSpeciesReferenceGlyph (const SpeciesReferenceGlyph* glyph);
        
   /**
    * Returns the number of species reference glyph objects.
@@ -505,6 +505,7 @@ public:
   virtual int getTypeCode () const;
 
 
+  /** @cond doxygenLibsbmlInternal */
   /**
    * Accepts the given SBMLVisitor.
    *
@@ -513,6 +514,7 @@ public:
    * sibling object (if available).
    */
   virtual bool accept (SBMLVisitor& v) const;
+  /** @endcond */
    
    
    /**
