@@ -127,7 +127,7 @@ public:
    *
    * @return the value of the "bindingStatus" attribute of this OutwardBindingSite as a FIX ME.
    */
-  virtual const BindingStatus_t getBindingStatus() const;
+  virtual BindingStatus_t getBindingStatus() const;
 
 
   /**
@@ -596,8 +596,21 @@ protected:
 
 };
 
+BEGIN_C_DECLS
 
 
+LIBSBML_EXTERN
+const char* 
+BindingStatus_toString(BindingStatus_t bindingStatus);
+
+
+LIBSBML_EXTERN
+BindingStatus_t 
+BindingStatus_fromString(const char* s);
+
+
+END_C_DECLS
+
 LIBSBML_CPP_NAMESPACE_END
 
 #endif  /*  __cplusplus  */
@@ -689,16 +702,6 @@ int
 OutwardBindingSite_isValidBindingStatusString(const char* s);
 
 
-LIBSBML_EXTERN
-const char* 
-BindingStatus_toString(BindingStatus_t bindingStatus);
-
-
-LIBSBML_EXTERN
-BindingStatus_t 
-BindingStatus_fromString(const char* s);
-
-
 END_C_DECLS
 LIBSBML_CPP_NAMESPACE_END
 
