@@ -13,7 +13,7 @@
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *
  * Copyright (C) 2006-2008 by the California Institute of Technology,
- *     Pasadena, CA, USA 
+ *     Pasadena, CA, USA
  *
  * Copyright (C) 2002-2005 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
@@ -35,11 +35,11 @@
 #include <sbml/ModifierSpeciesReference.h>
 
 
-  /** @cond doxygenLibsbmlInternal */
+/** @cond doxygenLibsbmlInternal */
 
 using namespace std;
 
-  /** @endcond doxygenLibsbmlInternal */
+/** @endcond doxygenLibsbmlInternal */
 
 
 LIBSBML_CPP_NAMESPACE_BEGIN
@@ -61,10 +61,10 @@ LIBSBML_CPP_NAMESPACE_BEGIN
 /*
  * Applies a Constraint<T> to an SBML object of type T.
  */
-template <typename T>
+ template <typename T>
 struct Apply : public unary_function<TConstraint<T>*, void>
 {
-  Apply (const Model& m, const T& o) : model(m), object(o) { }
+  Apply(const Model& m, const T& o) : model(m), object(o) { }
 
 
   void operator() (TConstraint<T>* constraint)
@@ -83,14 +83,14 @@ class ConstraintSet
 {
 public:
 
-   ConstraintSet () { }
-  ~ConstraintSet () { }
+  ConstraintSet() { }
+  ~ConstraintSet() { }
 
 
   /*
    * Adds a Constraint to this ConstraintSet.
    */
-  void add (TConstraint<T>* c)
+  void add(TConstraint<T>* c)
   {
     constraints.push_back(c);
   }
@@ -99,7 +99,7 @@ public:
    * Applies all Constraints in this ConstraintSet to the given SBML object
    * of type T.  Constraint violations are logged to Validator.
    */
-  void applyTo (const Model& model, const T& object)
+  void applyTo(const Model& model, const T& object)
   {
     for_each(constraints.begin(), constraints.end(), Apply<T>(model, object));
   }
@@ -107,7 +107,7 @@ public:
   /*
    * @return true if this ConstraintSet is empty, false otherwise.
    */
-  bool empty () const
+  bool empty() const
   {
     return constraints.empty();
   }
@@ -144,7 +144,6 @@ struct MultiValidatorConstraints
   ConstraintSet<SpeciesTypeInstance>   mSpeciesTypeInstance;
   ConstraintSet<InSpeciesTypeBond>     mInSpeciesTypeBond;
   ConstraintSet<OutwardBindingSite>    mOutwardBindingSite;
-  ConstraintSet<SpeciesFeatureChange>  mSpeciesFeatureChange;
   ConstraintSet<SpeciesFeatureType>    mSpeciesFeatureType;
   ConstraintSet<SpeciesTypeComponentIndex>      mSpeciesTypeComponentIndex;
   ConstraintSet<SpeciesFeature>        mSpeciesFeature;
@@ -152,10 +151,10 @@ struct MultiValidatorConstraints
   ConstraintSet<MultiSpeciesType>      mMultiSpeciesType;
   ConstraintSet<Compartment>           mCompartment;
   ConstraintSet<Species>           	   mSpecies;
-  map<VConstraint*,bool> ptrMap;
+  map<VConstraint*, bool> ptrMap;
 
-  ~MultiValidatorConstraints ();
-  void add (VConstraint* c);
+  ~MultiValidatorConstraints();
+  void add(VConstraint* c);
 };
 
 
@@ -168,14 +167,14 @@ struct MultiValidatorConstraints
  * ConstraintSet<ModifierSimpleSpeciesReference>), a pointer map is used for
  * avoiding segmentation fault caused by deleting the same pointer twice.
  */
-MultiValidatorConstraints::~MultiValidatorConstraints ()
+MultiValidatorConstraints::~MultiValidatorConstraints()
 {
-  map<VConstraint*,bool>::iterator it = ptrMap.begin();
+  map<VConstraint*, bool>::iterator it = ptrMap.begin();
 
-  while(it != ptrMap.end())
+  while (it != ptrMap.end())
   {
-     if(it->second) delete it->first;
-     ++it;
+    if (it->second) delete it->first;
+    ++it;
   }
 }
 
@@ -184,102 +183,96 @@ MultiValidatorConstraints::~MultiValidatorConstraints ()
  * Adds the given Contraint to the appropriate ConstraintSet.
  */
 void
-MultiValidatorConstraints::add (VConstraint* c)
+MultiValidatorConstraints::add(VConstraint* c)
 {
   if (c == NULL) return;
 
-  ptrMap.insert(pair<VConstraint*,bool>(c,true));
+  ptrMap.insert(pair<VConstraint*, bool>(c, true));
 
-  if (dynamic_cast< TConstraint<SBMLDocument>* >(c) != NULL)
+  if (dynamic_cast<TConstraint<SBMLDocument>*>(c) != NULL)
   {
-    mSBMLDocument.add( static_cast< TConstraint<SBMLDocument>* >(c) );
+    mSBMLDocument.add(static_cast<TConstraint<SBMLDocument>*>(c));
     return;
   }
 
-  if (dynamic_cast< TConstraint<Model>* >(c) != NULL)
+  if (dynamic_cast<TConstraint<Model>*>(c) != NULL)
   {
-    mModel.add( static_cast< TConstraint<Model>* >(c) );
+    mModel.add(static_cast<TConstraint<Model>*>(c));
     return;
   }
-  if (dynamic_cast< TConstraint<PossibleSpeciesFeatureValue>* >(c) != NULL)
+  if (dynamic_cast<TConstraint<PossibleSpeciesFeatureValue>*>(c) != NULL)
   {
-    mPossibleSpeciesFeatureValue.add( static_cast< TConstraint<PossibleSpeciesFeatureValue>* >(c) );
+    mPossibleSpeciesFeatureValue.add(static_cast<TConstraint<PossibleSpeciesFeatureValue>*>(c));
     return;
   }
 
-  if (dynamic_cast< TConstraint<SpeciesFeatureValue>* >(c) != NULL)
+  if (dynamic_cast<TConstraint<SpeciesFeatureValue>*>(c) != NULL)
   {
-    mSpeciesFeatureValue.add( static_cast< TConstraint<SpeciesFeatureValue>* >(c) );
+    mSpeciesFeatureValue.add(static_cast<TConstraint<SpeciesFeatureValue>*>(c));
     return;
   }
 
-  if (dynamic_cast< TConstraint<CompartmentReference>* >(c) != NULL)
+  if (dynamic_cast<TConstraint<CompartmentReference>*>(c) != NULL)
   {
-    mCompartmentReference.add( static_cast< TConstraint<CompartmentReference>* >(c) );
+    mCompartmentReference.add(static_cast<TConstraint<CompartmentReference>*>(c));
     return;
   }
 
-  if (dynamic_cast< TConstraint<SpeciesTypeInstance>* >(c) != NULL)
+  if (dynamic_cast<TConstraint<SpeciesTypeInstance>*>(c) != NULL)
   {
-    mSpeciesTypeInstance.add( static_cast< TConstraint<SpeciesTypeInstance>* >(c) );
+    mSpeciesTypeInstance.add(static_cast<TConstraint<SpeciesTypeInstance>*>(c));
     return;
   }
 
-  if (dynamic_cast< TConstraint<InSpeciesTypeBond>* >(c) != NULL)
+  if (dynamic_cast<TConstraint<InSpeciesTypeBond>*>(c) != NULL)
   {
-    mInSpeciesTypeBond.add( static_cast< TConstraint<InSpeciesTypeBond>* >(c) );
+    mInSpeciesTypeBond.add(static_cast<TConstraint<InSpeciesTypeBond>*>(c));
     return;
   }
 
-  if (dynamic_cast< TConstraint<OutwardBindingSite>* >(c) != NULL)
+  if (dynamic_cast<TConstraint<OutwardBindingSite>*>(c) != NULL)
   {
-    mOutwardBindingSite.add( static_cast< TConstraint<OutwardBindingSite>* >(c) );
+    mOutwardBindingSite.add(static_cast<TConstraint<OutwardBindingSite>*>(c));
     return;
   }
 
-  if (dynamic_cast< TConstraint<SpeciesFeatureChange>* >(c) != NULL)
+  if (dynamic_cast<TConstraint<SpeciesFeatureType>*>(c) != NULL)
   {
-    mSpeciesFeatureChange.add( static_cast< TConstraint<SpeciesFeatureChange>* >(c) );
+    mSpeciesFeatureType.add(static_cast<TConstraint<SpeciesFeatureType>*>(c));
     return;
   }
 
-  if (dynamic_cast< TConstraint<SpeciesFeatureType>* >(c) != NULL)
+  if (dynamic_cast<TConstraint<SpeciesTypeComponentIndex>*>(c) != NULL)
   {
-    mSpeciesFeatureType.add( static_cast< TConstraint<SpeciesFeatureType>* >(c) );
+    mSpeciesTypeComponentIndex.add(static_cast<TConstraint<SpeciesTypeComponentIndex>*>(c));
     return;
   }
 
-  if (dynamic_cast< TConstraint<SpeciesTypeComponentIndex>* >(c) != NULL)
+  if (dynamic_cast<TConstraint<SpeciesFeature>*>(c) != NULL)
   {
-    mSpeciesTypeComponentIndex.add( static_cast< TConstraint<SpeciesTypeComponentIndex>* >(c) );
+    mSpeciesFeature.add(static_cast<TConstraint<SpeciesFeature>*>(c));
     return;
   }
 
-  if (dynamic_cast< TConstraint<SpeciesFeature>* >(c) != NULL)
+  if (dynamic_cast<TConstraint<SpeciesTypeComponentMapInProduct>*>(c) != NULL)
   {
-    mSpeciesFeature.add( static_cast< TConstraint<SpeciesFeature>* >(c) );
+    mSpeciesTypeComponentMapInProduct.add(static_cast<TConstraint<SpeciesTypeComponentMapInProduct>*>(c));
     return;
   }
 
-  if (dynamic_cast< TConstraint<SpeciesTypeComponentMapInProduct>* >(c) != NULL)
+  if (dynamic_cast<TConstraint<MultiSpeciesType>*>(c) != NULL)
   {
-    mSpeciesTypeComponentMapInProduct.add( static_cast< TConstraint<SpeciesTypeComponentMapInProduct>* >(c) );
+    mMultiSpeciesType.add(static_cast<TConstraint<MultiSpeciesType>*>(c));
     return;
   }
-
-  if (dynamic_cast< TConstraint<MultiSpeciesType>* >(c) != NULL)
+  if (dynamic_cast<TConstraint<Compartment>*>(c) != NULL)
   {
-    mMultiSpeciesType.add( static_cast< TConstraint<MultiSpeciesType>* >(c) );
+    mCompartment.add(static_cast<TConstraint<Compartment>*>(c));
     return;
   }
-  if (dynamic_cast< TConstraint<Compartment>* >(c) != NULL)
+  if (dynamic_cast<TConstraint<Species>*>(c) != NULL)
   {
-    mCompartment.add( static_cast< TConstraint<Compartment>* >(c) );
-    return;
-  }
-  if (dynamic_cast< TConstraint<Species>* >(c) != NULL)
-  {
-    mSpecies.add( static_cast< TConstraint<Species>* >(c) );
+    mSpecies.add(static_cast<TConstraint<Species>*>(c));
     return;
   }
 
@@ -302,114 +295,108 @@ MultiValidatorConstraints::add (VConstraint* c)
  * A ValidatingVisitor overrides each visit method to validate the given
  * SBML object.
  */
-class MultiValidatingVisitor: public SBMLVisitor
+class MultiValidatingVisitor : public SBMLVisitor
 {
 public:
 
-  MultiValidatingVisitor (MultiValidator& v, const Model& m) : v(v), m(m) { }
+  MultiValidatingVisitor(MultiValidator& v, const Model& m) : v(v), m(m) { }
 
 
   using SBMLVisitor::visit;
 
   // model
-  virtual void visit (const Model &x)
+  virtual void visit(const Model &x)
   {
     v.mMultiConstraints->mModel.applyTo(m, x);
     v.mMultiConstraints->mModel.empty();
   }
 
-  bool visit (const PossibleSpeciesFeatureValue &x)
+  bool visit(const PossibleSpeciesFeatureValue &x)
   {
     v.mMultiConstraints->mPossibleSpeciesFeatureValue.applyTo(m, x);
     return !v.mMultiConstraints->mPossibleSpeciesFeatureValue.empty();
   }
 
-  bool visit (const SpeciesFeatureValue &x)
+  bool visit(const SpeciesFeatureValue &x)
   {
     v.mMultiConstraints->mSpeciesFeatureValue.applyTo(m, x);
     return !v.mMultiConstraints->mSpeciesFeatureValue.empty();
   }
 
-  bool visit (const CompartmentReference &x)
+  bool visit(const CompartmentReference &x)
   {
     v.mMultiConstraints->mCompartmentReference.applyTo(m, x);
     return !v.mMultiConstraints->mCompartmentReference.empty();
   }
 
-  bool visit (const SpeciesTypeInstance &x)
+  bool visit(const SpeciesTypeInstance &x)
   {
     v.mMultiConstraints->mSpeciesTypeInstance.applyTo(m, x);
     return !v.mMultiConstraints->mSpeciesTypeInstance.empty();
   }
 
-  bool visit (const InSpeciesTypeBond &x)
+  bool visit(const InSpeciesTypeBond &x)
   {
     v.mMultiConstraints->mInSpeciesTypeBond.applyTo(m, x);
     return !v.mMultiConstraints->mInSpeciesTypeBond.empty();
   }
 
-  bool visit (const OutwardBindingSite &x)
+  bool visit(const OutwardBindingSite &x)
   {
     v.mMultiConstraints->mOutwardBindingSite.applyTo(m, x);
     return !v.mMultiConstraints->mOutwardBindingSite.empty();
   }
 
-  bool visit (const SpeciesFeatureChange &x)
-  {
-    v.mMultiConstraints->mSpeciesFeatureChange.applyTo(m, x);
-    return !v.mMultiConstraints->mSpeciesFeatureChange.empty();
-  }
-
-  bool visit (const SpeciesFeatureType &x)
+  bool visit(const SpeciesFeatureType &x)
   {
     v.mMultiConstraints->mSpeciesFeatureType.applyTo(m, x);
     return !v.mMultiConstraints->mSpeciesFeatureType.empty();
   }
 
-  bool visit (const SpeciesTypeComponentIndex &x)
+  bool visit(const SpeciesTypeComponentIndex &x)
   {
     v.mMultiConstraints->mSpeciesTypeComponentIndex.applyTo(m, x);
     return !v.mMultiConstraints->mSpeciesTypeComponentIndex.empty();
   }
 
-  bool visit (const SpeciesFeature &x)
+  bool visit(const SpeciesFeature &x)
   {
     v.mMultiConstraints->mSpeciesFeature.applyTo(m, x);
     return !v.mMultiConstraints->mSpeciesFeature.empty();
   }
 
-  bool visit (const SpeciesTypeComponentMapInProduct &x)
+  bool visit(const SpeciesTypeComponentMapInProduct &x)
   {
     v.mMultiConstraints->mSpeciesTypeComponentMapInProduct.applyTo(m, x);
     return !v.mMultiConstraints->mSpeciesTypeComponentMapInProduct.empty();
   }
 
-  bool visit (const MultiSpeciesType &x)
+  bool visit(const MultiSpeciesType &x)
   {
     v.mMultiConstraints->mMultiSpeciesType.applyTo(m, x);
     return !v.mMultiConstraints->mMultiSpeciesType.empty();
   }
 
-  bool visit (const Compartment &x)
+  bool visit(const Compartment &x)
   {
     v.mMultiConstraints->mCompartment.applyTo(m, x);
     return !v.mMultiConstraints->mCompartment.empty();
   }
-  bool visit (const Species &x)
+  bool visit(const Species &x)
   {
     v.mMultiConstraints->mSpecies.applyTo(m, x);
     return !v.mMultiConstraints->mSpecies.empty();
   }
-//  bool visit (const Reaction &x)
-//  {
-//    v.mMultiConstraints->mReactions.applyTo(m, x);
-//    return !v.mMultiConstraints->mReactions.empty();
-//  }
-//  bool visit (const ASTNode &x)
-//  {
-//    v.mMultiConstraints->mASTNodes.applyTo(m, x);
-//    return !v.mMultiConstraints->mASTNodes.empty();
-//  }
+  //  bool visit (const Reaction &x)
+  //  {
+  //    v.mMultiConstraints->mReactions.applyTo(m, x);
+  //    return !v.mMultiConstraints->mReactions.empty();
+  //  }
+  //  bool visit (const ASTNode &x)
+  //  {
+  //    v.mMultiConstraints->mASTNodes.applyTo(m, x);
+  //    return !v.mMultiConstraints->mASTNodes.empty();
+  //  }
   virtual bool visit(const SBase &x)
   {
     if (x.getPackageName() != "multi")
@@ -451,10 +438,6 @@ public:
       {
         return visit((const OutwardBindingSite&)x);
       }
-      else if (code == SBML_MULTI_SPECIES_FEATURE_CHANGE)
-      {
-        return visit((const SpeciesFeatureChange&)x);
-      }
       else if (code == SBML_MULTI_SPECIES_FEATURE_TYPE)
       {
         return visit((const SpeciesFeatureType&)x);
@@ -475,10 +458,10 @@ public:
       {
         return visit((const MultiSpeciesType&)x);
       }
-      else 
+      else
       {
         return SBMLVisitor::visit(x);
-      } 
+      }
     }
   }
 
@@ -499,14 +482,14 @@ protected:
 // ----------------------------------------------------------------------
 
 
-MultiValidator::MultiValidator (const SBMLErrorCategory_t category):
-  Validator(category)
+MultiValidator::MultiValidator(const SBMLErrorCategory_t category) :
+Validator(category)
 {
   mMultiConstraints = new MultiValidatorConstraints();
 }
 
 
-MultiValidator::~MultiValidator ()
+MultiValidator::~MultiValidator()
 {
   delete mMultiConstraints;
 }
@@ -516,7 +499,7 @@ MultiValidator::~MultiValidator ()
  * Adds the given Contraint to this validator.
  */
 void
-MultiValidator::addConstraint (VConstraint* c)
+MultiValidator::addConstraint(VConstraint* c)
 {
   mMultiConstraints->add(c);
 }
@@ -536,7 +519,7 @@ MultiValidator::addConstraint (VConstraint* c)
  * @return the number of validation errors that occurred.
  */
 unsigned int
-MultiValidator::validate (const SBMLDocument& d)
+MultiValidator::validate(const SBMLDocument& d)
 {
 
   const Model* m = d.getModel();
@@ -552,13 +535,13 @@ MultiValidator::validate (const SBMLDocument& d)
     // Compartment
     for (unsigned int i = 0; i < m->getNumCompartments(); i++)
     {
-      ACCEPT_MULTI(m->getCompartment(i),vv);
+      ACCEPT_MULTI(m->getCompartment(i), vv);
     }
 
     //  Species
     for (unsigned int i = 0; i < m->getNumSpecies(); i++)
     {
-      ACCEPT_MULTI(m->getSpecies(i),vv);
+      ACCEPT_MULTI(m->getSpecies(i), vv);
     }
 
     // ListOfReactions
@@ -571,33 +554,35 @@ MultiValidator::validate (const SBMLDocument& d)
 
       for (unsigned int j = 0; j < r->getNumReactants(); j++)
       {
-        ACCEPT_MULTI(r->getReactant(j),vv);
+        ACCEPT_MULTI(r->getReactant(j), vv);
       }
       for (unsigned int j = 0; j < r->getNumProducts(); j++)
       {
-        ACCEPT_MULTI(r->getProduct(j),vv);
+        ACCEPT_MULTI(r->getProduct(j), vv);
       }
       for (unsigned int j = 0; j < r->getNumModifiers(); j++)
       {
-        ACCEPT_MULTI(r->getModifier(j),vv);
+        ACCEPT_MULTI(r->getModifier(j), vv);
       }
 
       const KineticLaw * kineticLaw = r->getKineticLaw();
       if (kineticLaw) {
-          const ASTNode * math = kineticLaw->getMath();
-          // TODO for validation of ci elements
-			const List * listNumberNodes = math->getListOfNodes((ASTNodePredicate)ASTNode_isNumber);
+        const ASTNode * math = kineticLaw->getMath();
+        // TODO for validation of ci elements
+        List * listNumberNodes = math->getListOfNodes((ASTNodePredicate)ASTNode_isNumber);
 
-			for (unsigned int i = 0; i < listNumberNodes->getSize(); i++)
-			{
-				const ASTNode * node = static_cast<const ASTNode *> (listNumberNodes->get(i));
-				if (node != NULL) {
-					const MultiASTPlugin * astPlugin = static_cast<const MultiASTPlugin*>(node->getPlugin("multi"));
-					if (astPlugin != NULL) {
-//						astPlugin-
-					}
-				}
-			}
+        for (unsigned int i = 0; i < listNumberNodes->getSize(); i++)
+        {
+          const ASTNode * node = static_cast<const ASTNode *> (listNumberNodes->get(i));
+          if (node != NULL) {
+            const MultiASTPlugin * astPlugin = static_cast<const MultiASTPlugin*>(node->getPlugin("multi"));
+            if (astPlugin != NULL) {
+              //						astPlugin-
+            }
+          }
+        }
+
+        delete listNumberNodes;
 
       }
     }
@@ -605,7 +590,7 @@ MultiValidator::validate (const SBMLDocument& d)
   }
 
   /* ADD ANY OTHER OBJECTS THAT HAVE PLUGINS */
-  
+
   return (unsigned int)mFailures.size();
 }
 
@@ -617,19 +602,23 @@ MultiValidator::validate (const SBMLDocument& d)
  * @return the number of validation errors that occurred.
  */
 unsigned int
-MultiValidator::validate (const std::string& filename)
+MultiValidator::validate(const std::string& filename)
 {
 
   SBMLReader    reader;
-  SBMLDocument& d = *reader.readSBML(filename);
+  SBMLDocument *d = reader.readSBML(filename);
 
 
-  for (unsigned int n = 0; n < d.getNumErrors(); ++n)
+  for (unsigned int n = 0; n < d->getNumErrors(); ++n)
   {
-    logFailure( *d.getError(n) );
+    logFailure(*d->getError(n));
   }
 
-  return validate(d);
+  int result = validate(*d);
+
+  delete d;
+
+  return result;
 }
 
 
