@@ -190,41 +190,6 @@ static bool __isSpeciesTypeComponent(const Model & model, const std::string & co
   return found;
 }
 
-static bool __isSpeciesTypeIndexComponent(const Model & model, const std::string & componentId)
-{
-  bool found = false;
-  const MultiModelPlugin * mPlugin =
-      dynamic_cast<const MultiModelPlugin*>(model.getPlugin("multi"));
-  if (mPlugin != 0) {
-      for (unsigned int i = 0; !found && i < mPlugin->getNumMultiSpeciesTypes(); i++) {
-          const MultiSpeciesType * speciesType = mPlugin->getMultiSpeciesType(i);
-          if (speciesType) {
-
-        	  const SpeciesTypeComponentIndex * speciesTypeComponentIndex = speciesType->getSpeciesTypeComponentIndex(componentId);
-        	  found = (speciesTypeComponentIndex != NULL);
-          }
-      }
-  }
-  return found;
-}
-
-static bool __isSpeciesTypeInstanceComponent(const Model & model, const std::string & componentId)
-{
-  bool found = false;
-  const MultiModelPlugin * mPlugin =
-      dynamic_cast<const MultiModelPlugin*>(model.getPlugin("multi"));
-  if (mPlugin != 0) {
-      for (unsigned int i = 0; !found && i < mPlugin->getNumMultiSpeciesTypes(); i++) {
-          const MultiSpeciesType * speciesType = mPlugin->getMultiSpeciesType(i);
-          if (speciesType) {
-        	  const SpeciesTypeInstance * speciesTypeInstance = speciesType->getSpeciesTypeInstance(componentId);
-        	  found = speciesTypeInstance != NULL;
-          }
-      }
-  }
-  return found;
-}
-
 static bool __isSpeciesTypeInstanceOrIndex(const Model & model, const std::string & componentId)
 {
   bool found = false;
@@ -318,31 +283,42 @@ static bool __isSpeciesFeature(const Model & model, const std::string & speciesI
                         isSpeciesFeature = true;
                 }
             }
+
+            for(unsigned int i = 0; good && !isSpeciesFeature && i < speciesPlugin->getNumSubListOfSpeciesFeatures(); i++) {
+                const SubListOfSpeciesFeatures * subListOfSpeciesFeatures = speciesPlugin->getSubListOfSpeciesFeatures(i);
+                for (unsigned int j = 0; good && !isSpeciesFeature && j < subListOfSpeciesFeatures->getNumSpeciesFeatures(); j++) {
+                    const SpeciesFeature * speciesFeature = subListOfSpeciesFeatures->get(j);
+                    if (speciesFeature->getId() == speciesFeatureId) {
+                         isSpeciesFeature = true;
+                    }
+                }
+            }
+
         }
 
         return isSpeciesFeature;
 }
 
-static bool __isBindingSiteSpeciesTypeComponent(const Model & model, const std::string & componentId)
-{
-  bool found = false;
-  const MultiModelPlugin * mPlugin =
-      dynamic_cast<const MultiModelPlugin*>(model.getPlugin("multi"));
-  if (mPlugin != 0) {
-
-	  if (__isSpeciesTypeComponent(model, componentId)) {
-
-	  }
-	  else if (__isSpeciesTypeInstanceComponent(model, componentId)) {
-
-	  }
-	  else if (__isSpeciesTypeIndexComponent(model, componentId)) {
-
-	  }
-
-  }
-  return found;
-}
+//static bool __isBindingSiteSpeciesTypeComponent(const Model & model, const std::string & componentId)
+//{
+//  bool found = false;
+//  const MultiModelPlugin * mPlugin =
+//      dynamic_cast<const MultiModelPlugin*>(model.getPlugin("multi"));
+//  if (mPlugin != 0) {
+//
+//	  if (__isSpeciesTypeComponent(model, componentId)) {
+//
+//	  }
+//	  else if (__isSpeciesTypeInstanceComponent(model, componentId)) {
+//
+//	  }
+//	  else if (__isSpeciesTypeIndexComponent(model, componentId)) {
+//
+//	  }
+//
+//  }
+//  return found;
+//}
 
 
 
@@ -564,7 +540,6 @@ END_CONSTRAINT
 // MultiSptIns_AllowedCoreAtts           = 7020801 - caught at read at 'SpeciesTypeInstance::readAttributes()'
 // MultiSptIns_AllowedCoreElts           = 7020802 - caught at read at 'SBase::logUnknownElement()'
 // MultiSptIns_AllowedMultiAtts          = 7020803 - caught at read at 'SpeciesTypeInstance::readAttributes()'
-// MultiSptIns_OccAtt_Ref                = 7020804 - caught at read at 'SpeciesTypeInstance::readAttributes()'
 
 // MultiSptIns_SptAtt_Ref                = 7020805
 /*!< SpeciesTypeInstance: 'speciesType' must be the 'id' of a speciesType */
@@ -641,18 +616,6 @@ START_CONSTRAINT (MultiSptCpoInd_IdParAtt_Ref, SpeciesTypeComponentIndex, specie
 }
 END_CONSTRAINT
 
-// MultiSptCpoInd_OccAtt_Ref             = 7020908 - caught at read at 'SpeciesTypeComponentIndex::readAttributes()'
-// MultiLofDenSptCpoInds_NoEmpty         = 7020909 - caught at read at 'SBase::checkListOfPopulated()', TODO: need update if core is revised.
-// MultiLofDenSptCpoInds_AllowedAtts     = 7020910 - caught at read at 'DenotedSpeciesTypeComponentIndex::readAttributes()'
-// MultiLofDenSptCpoInds_Elts            = 7020911 - caught at read at 'SBase::logUnknownElement()'
-
-//************************************
-// Rules for DenotedSpeciesTypeComponentIndex objects
-
-// MultiDenSptCpoInd_AllowedCoreAtts     = 7021001 - caught at read at 'DenotedSpeciesTypeComponentIndex::readAttributes()'
-// MultiDenSptCpoInd_AllowedCoreElts     = 7021002 - caught at read at 'SBase::logUnknownElement()'
-// MultiDenSptCpoInd_AllowedMultiAtts    = 7021003 - caught at read at 'DenotedSpeciesTypeComponentIndex::readAttributes()'
-
 //************************************
 // Rules for InSpeciesTypeBond objects
 
@@ -722,10 +685,30 @@ END_CONSTRAINT
 // MultiExSpe_NoEmptyListOfDefs          = 7021203 - caught at read at 'SBase::checkListOfPopulated()', TODO: need update if core is revised.
 // MultiLofOutBsts_AllowedAtts           = 7021204 - caught at read at 'OutwardBindingSite::readAttributes()'
 // MultiLofOutBsts_AllowedElts           = 7021205 - caught at read at 'SBase::logUnknownElement()'
-// MultiLofSpeFtrs_AllowedCoreAtts       = 7021206 - caught at read at 'SpeciesFeature::readAttributes()'
-// MultiLofSpeFtrs_AllowedMultiAtts      = 7021207 - caught at read at 'SpeciesFeature::readAttributes()'
-// MultiLofSpeFtrs_RelationAtt_Ref       = 7021208 - caught at read at 'ListOfSpeciesFeatures::readAttributes()'
+// MultiLofSpeFtrs_AllowedAtts           = 7021206 - caught at read at 'SpeciesFeature::readAttributes()'
+// MultiSubLofSpeFtrs_AllowedMultiAtts   = 7021207 - caught at read at 'SubListOfSpeciesFeatures::readAttributes()'
+// MultiSubLofSpeFtrs_RelationAtt_Ref    = 7021208 - caught at read at 'SubListOfSpeciesFeatures::readAttributes()'
 // MultiLofSpeFtrs_AllowedElts           = 7021209 - caught at read at 'SBase::logUnknownElement()'
+// MultiSubLofSpeFtrs_AllowedCoreAtts    = 7021210 - caught at read at 'SubListOfSpeciesFeatures::readAttributes()'
+// MultiSubLofSpeFtrs_AllowedElts        = 7021211 - caught at read at 'SBase::logUnknownElement()'
+
+// MultiSubLofSpeFtrs_CpoAtt_Ref         = 7021212
+/*!< SubListOfSpeciesFeatures: 'component' must be the 'id' of a 'SpeciesType' component */
+
+START_CONSTRAINT (MultiSubLofSpeFtrs_CpoAtt_Ref, SubListOfSpeciesFeatures, subListOfSpeciesFeatures)
+{
+  const MultiModelPlugin * mPlugin =
+      dynamic_cast<const MultiModelPlugin*>(m.getPlugin("multi"));
+
+  pre (mPlugin != 0);
+
+  std::string subLofSpeFtrsComponentId = subListOfSpeciesFeatures.getComponent();
+
+  const MultiSpeciesType * st = __getSpeciesTypeFromComponentId(m, subLofSpeFtrsComponentId);
+
+  inv(st != NULL);
+}
+END_CONSTRAINT
 
 //************************************
 // Rules for OutwardBindingSite objects
@@ -755,6 +738,44 @@ START_CONSTRAINT (MultiOutBst_CpoAtt_Ref, OutwardBindingSite, outwardBindingSite
 }
 END_CONSTRAINT
 
+// MultiOutBst_NotInBond                = 7021306
+/*!< OutwardBindingSite: An outwardBindingSite can not be in a bond of the species */
+
+START_CONSTRAINT (MultiOutBst_NotInBond, OutwardBindingSite, outwardBindingSite)
+{
+  // compare only component ids in bonds, TODO: check all possible component ids of binding site in bonds
+  const MultiModelPlugin * mPlugin =
+      dynamic_cast<const MultiModelPlugin*>(m.getPlugin("multi"));
+
+  pre (mPlugin != 0);
+
+  std::string bstComponentId = outwardBindingSite.getComponent();
+
+  const SBase * parent = outwardBindingSite.getParentSBMLObject()->getParentSBMLObject();
+  const Species * species = dynamic_cast<const Species *> (parent);
+  pre (species != 0);
+
+  const MultiSpeciesPlugin * spPlugin =
+		  dynamic_cast<const MultiSpeciesPlugin *>(species->getPlugin("multi"));
+  pre (spPlugin != 0);
+
+  std::string stId = spPlugin->getSpeciesType();
+
+  const MultiSpeciesType * st = mPlugin->getMultiSpeciesType(stId);
+  pre (st != 0);
+
+  bool found = false;
+  for (unsigned int i = 0; !found && i < st->getNumInSpeciesTypeBonds(); i++) {
+	const InSpeciesTypeBond * inSpeciesTypeBond = st->getInSpeciesTypeBond(i);
+	std::string bst1 = inSpeciesTypeBond->getBindingSite1();
+	inv(bst1 != bstComponentId);
+
+	std::string bst2 = inSpeciesTypeBond->getBindingSite2();
+	inv(bst2 != bstComponentId);
+  }
+}
+END_CONSTRAINT
+
 //************************************
 // Rules for SpeciesFeature objects
 
@@ -811,6 +832,9 @@ START_CONSTRAINT (MultiSpeFtr_OccAtt_Ref, SpeciesFeature, speciesFeature)
   pre (sbaseSpecies != 0);
 
   const Species * species = dynamic_cast<const Species *> (sbaseSpecies);
+  if (species == NULL) { // possible from subListOfSpeciesFeatures?
+      species = dynamic_cast<const Species *>(sbaseSpecies->getParentSBMLObject());
+  }
   pre (species != 0);
 
   const MultiSpeciesPlugin * spPlugin =
@@ -910,6 +934,9 @@ START_CONSTRAINT (MultiSpeFtrVal_ValAtt_Ref, SpeciesFeatureValue, speciesFeature
 
   // species
   const Species * species = dynamic_cast<const Species *>(sbaseSpecies);
+  if (species == NULL) { // possible from subListOfSpeciesFeatures?
+      species = dynamic_cast<const Species *>(sbaseSpecies->getParentSBMLObject());
+  }
 
   if (species) {
     const MultiSpeciesPlugin * spPlugin =
@@ -1108,90 +1135,6 @@ START_CONSTRAINT (MultiSptCpoMapInPro_ProCpoAtt_Ref, SpeciesTypeComponentMapInPr
 }
 END_CONSTRAINT
 
-// MultiLofSpeFtrChgs_NoEmpty            = 7021907 - caught at read at 'SBase::checkListOfPopulated()', TODO: need update if core is revised.
-// MultiLofSpeFtrChgs_AllowedAtts        = 7021908 - caught at read at 'SpeciesFeatureChange::readAttributes()'
-// MultiLofSpeFtrChgs_AllowedElts        = 7021909 - caught at read at 'SBase::logUnknownElement()'
-
-//************************************
-// Rules for SpeciesFeatureChange objects
-
-// MultiSpeFtrChg_AllowedCoreAtts        = 7022001 - caught at read at 'SpeciesFeatureChange::readAttributes()'
-// MultiSpeFtrChg_AllowedCoreElts        = 7022002 - caught at read at 'SBase::logUnknownElement()'
-// MultiSpeFtrChg_AllowedMultiAtts       = 7022003 - caught at read at 'SpeciesFeatureChange::readAttributes()'
-
-// MultiSpeFtrChg_RctSpeFtrAtt_Ref       = 7022004
-/*!< SpeciesFeatureChange: 'reactantSpeciesFeature' must be the 'id' of a speciesFeature */
-
-START_CONSTRAINT (MultiSpeFtrChg_RctSpeFtrAtt_Ref, SpeciesFeatureChange, speciesFeatureChange)
-{
-    std::string reactantSpeciesFeatureId =
-        speciesFeatureChange.getReactantSpeciesFeature();
-
-    // parent of map -- list
-    const SBase * sbaseListOfSpeciesFeatureChanges = speciesFeatureChange.getParentSBMLObject();
-    pre (sbaseListOfSpeciesFeatureChanges != NULL);
-
-
-    // parent of map list -- speciesReference
-    const SBase * sbaseSpeciesTypeComponentMapInProduct = sbaseListOfSpeciesFeatureChanges->getParentSBMLObject();
-    const SpeciesTypeComponentMapInProduct * stcmip = dynamic_cast<const SpeciesTypeComponentMapInProduct *> (sbaseSpeciesTypeComponentMapInProduct);
-    pre (stcmip != NULL);
-
-    std::string reactantId = stcmip->getReactant();
-
-    const SBase * sbaseListSpeciesTypeComponentMapsInProduct =
-                sbaseSpeciesTypeComponentMapInProduct->getParentSBMLObject();
-    pre (sbaseListSpeciesTypeComponentMapsInProduct != NULL);
-
-    const SBase * sbaseProduct = sbaseListSpeciesTypeComponentMapsInProduct->getParentSBMLObject();
-    pre (sbaseProduct != NULL);
-
-    const SBase * sbaseListOfProducts = sbaseProduct->getParentSBMLObject();
-    pre (sbaseListOfProducts != NULL);
-
-    const SBase * sbaseReaction = sbaseListOfProducts->getParentSBMLObject();
-    const Reaction * reaction = dynamic_cast<const Reaction *> (sbaseReaction);
-    pre (reaction != NULL);
-
-    const SpeciesReference * reactant = reaction->getReactant(reactantId);
-    pre (reactant != NULL);
-
-    std::string speciesId = reactant->getSpecies();
-
-    inv(__isSpeciesFeature(m, speciesId, reactantSpeciesFeatureId));
-  }
-END_CONSTRAINT
-
-// MultiSpeFtrChg_ProSpeFtrAtt_Ref       = 7022005
-/*!< SpeciesFeatureChange: 'productSpeciesFeature' must be the 'id' of a speciesFeature */
-
-START_CONSTRAINT (MultiSpeFtrChg_ProSpeFtrAtt_Ref, SpeciesFeatureChange, speciesFeatureChange)
-{
-    std::string productSpeciesFeatureId =
-        speciesFeatureChange.getProductSpeciesFeature();
-
-    // parent of map -- list
-    const SBase * sbaseListOfSpeciesFeatureChanges = speciesFeatureChange.getParentSBMLObject();
-    pre (sbaseListOfSpeciesFeatureChanges != NULL);
-
-    // parent of map list -- speciesReference
-    const SBase * sbaseSpeciesTypeComponentMapInProduct = sbaseListOfSpeciesFeatureChanges->getParentSBMLObject();
-    pre (sbaseSpeciesTypeComponentMapInProduct != NULL);
-
-    const SBase * sbaseListSpeciesTypeComponentMapsInProduct =
-                sbaseSpeciesTypeComponentMapInProduct->getParentSBMLObject();
-    pre (sbaseListSpeciesTypeComponentMapsInProduct != NULL);
-
-    const SBase * sbaseSpeciesReference =
-    		sbaseListSpeciesTypeComponentMapsInProduct->getParentSBMLObject();
-    const SpeciesReference * product =
-                    dynamic_cast<const SpeciesReference*>(sbaseSpeciesReference);
-    pre (product != NULL);
-
-    std::string speciesId = product->getSpecies();
-    inv( __isSpeciesFeature(m, speciesId, productSpeciesFeatureId));
-  }
-END_CONSTRAINT
 
 //************************************
 // Rules for extended ci elements in Math objects
