@@ -8,7 +8,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -178,8 +178,6 @@ QualModelPlugin::createObject(XMLInputStream& stream)
 
 
 /** @cond doxygenLibsbmlInternal */
-
-
 bool 
 QualModelPlugin::accept(SBMLVisitor& v) const
 {
@@ -198,8 +196,6 @@ QualModelPlugin::accept(SBMLVisitor& v) const
   }
   return true;
 }
-
-
 /** @endcond */
 
 
@@ -219,19 +215,6 @@ QualModelPlugin::writeElements (XMLOutputStream& stream) const
 /** @endcond */
 
 
-/** @cond doxygenLibsbmlInternal */
-/* default for components that have no required elements */
-bool
-QualModelPlugin::hasRequiredElements() const
-{
-  bool allPresent = true;
-
-  return allPresent;
-}
-/** @endcond */
-
-
-
 /*
  *
  *  (EXTENSION) Additional public functions
@@ -239,7 +222,6 @@ QualModelPlugin::hasRequiredElements() const
  */  
 
 /** @cond doxygenLibsbmlInternal */
-
 int 
 QualModelPlugin::appendFrom(const Model* model)
 {
@@ -411,11 +393,8 @@ QualModelPlugin::addQualitativeSpecies (const QualitativeSpecies* qual)
   }
   else
   {
-    mQualitativeSpecies.append(qual);
+    return mQualitativeSpecies.append(qual);
   }
-
-  return LIBSBML_OPERATION_SUCCESS;
-
 }
 /** @endcond */
 
@@ -596,11 +575,8 @@ QualModelPlugin::addTransition (const Transition* qual)
   }
   else
   {
-    mTransitions.append(qual);
+    return mTransitions.append(qual);
   }
-
-  return LIBSBML_OPERATION_SUCCESS;
-
 }
 /** @endcond */
 
