@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -360,6 +360,25 @@ List::transferFrom(List* list)
   list->size = 0;
 }
 
+
+/** @cond doxygenLibsbmlInternal */
+ListIterator 
+List::begin() 
+{ 
+  return ListIterator(head); 
+}
+/** @endcond */
+
+
+/** @cond doxygenLibsbmlInternal */
+ListIterator 
+List::end() 
+{ 
+  return ListIterator(0); 
+}
+/** @endcond */
+
+
 /** @cond doxygenLibsbmlInternal */
 void 
 List::deleteListAndChildrenWith(List* list, ListDeleteItemFunc delteFunc)
@@ -383,7 +402,6 @@ List::deleteListAndChildrenWith(List* list, ListDeleteItemFunc delteFunc)
 
 #endif /* __cplusplus */
 /** @cond doxygenIgnored */
-
 /**
  * @if conly
  * @memberof List_t
@@ -544,6 +562,5 @@ List_size (const List_t *lst)
 }
 
 LIBSBML_CPP_NAMESPACE_END
-
 /** @endcond */
 
