@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -705,6 +705,30 @@ SBMLInternalValidator::checkL2v4Compatibility ()
 
 
 
+/*
+ * Performs a set of semantic consistency checks on the document to establish
+ * whether it is compatible with L2v4 and can be converted.  Query
+ * the results by calling getNumErrors() and getError().
+ *
+ * @return the number of failed checks (errors) encountered.
+ */
+unsigned int
+SBMLInternalValidator::checkL2v5Compatibility ()
+{
+  if (getModel() == NULL) return 0;
+
+  // use the L2V4 validator as it is identical
+  L2v4CompatibilityValidator validator;
+  validator.init();
+
+  unsigned int nerrors = validator.validate(*getDocument());
+  if (nerrors > 0) getErrorLog()->add( validator.getFailures() );
+
+  return nerrors;
+}
+
+
+
 /*
  * Performs a set of semantic consistency checks on the document to establish
  * whether it is compatible with L2v1 and can be converted.  Query
@@ -761,8 +785,6 @@ unsigned int
 }
 
 /** @cond doxygenIgnored */
-
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_END
