@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -128,7 +128,9 @@ public:
 
 protected:
 
+  /** @cond doxygenLibsbmlInternal */
   std::list< TConstraint<T>* > constraints;
+  /** @endcond */
 };
 
 
@@ -175,6 +177,7 @@ struct ValidatorConstraints
   ConstraintSet<CompartmentType>          mCompartmentType;
   ConstraintSet<SpeciesType>              mSpeciesType;
   ConstraintSet<Priority>                 mPriority;
+  ConstraintSet<LocalParameter>           mLocalParameter;
 
   map<VConstraint*,bool> ptrMap;
 
@@ -391,6 +394,12 @@ ValidatorConstraints::add (VConstraint* c)
     return;
   }
 
+  if (dynamic_cast< TConstraint<LocalParameter>* >(c) != NULL)
+  {
+    mLocalParameter.add( static_cast< TConstraint<LocalParameter>* >(c) );
+    return;
+  }
+
 }
 
 // ----------------------------------------------------------------------
@@ -414,7 +423,7 @@ class ValidatingVisitor: public SBMLVisitor
 {
 public:
 
-  ValidatingVisitor (Validator& v, const Model& m) : v(v), m(m) { }
+  ValidatingVisitor (Validator& validator, const Model& model) : v(validator), m(model) { }
 
 
   void visit (const SBMLDocument& x)
@@ -496,8 +505,16 @@ public:
 
   bool visit (const Parameter& x)
   {
-    v.mConstraints->mParameter.applyTo(m, x);
-    return !v.mConstraints->mParameter.empty();
+    if (x.getTypeCode() == SBML_LOCAL_PARAMETER)
+    {
+      return visit(dynamic_cast<const LocalParameter&>(x));
+    }
+    else
+    {
+      v.mConstraints->mParameter.applyTo(m, x);
+      return !v.mConstraints->mParameter.empty();
+    }
+
   }
 
 
@@ -623,11 +640,19 @@ public:
     return !v.mConstraints->mSpeciesType.empty();
   }
 
+  bool visit (const LocalParameter& x)
+  {
+    v.mConstraints->mLocalParameter.applyTo(m, x);
+    return !v.mConstraints->mLocalParameter.empty();
+  }
+
 
 protected:
 
+  /** @cond doxygenLibsbmlInternal */
   Validator&   v;
   const Model& m;
+  /** @endcond */
 };
 
 
@@ -714,29 +739,29 @@ Validator::logFailure (const SBMLError& msg)
 class MatchId
 {
 public:
-  MatchId(unsigned int id) : id(id) {};
+  MatchId(unsigned int id) : mId(id) {};
 
   bool operator() (XMLError e) const
   {
-    return e.getErrorId() == id;
+    return e.getErrorId() == mId;
   };
 
 private:
-  unsigned int id;
+  unsigned int mId;
 };
 
 class DontMatchId
 {
 public:
-  DontMatchId(unsigned int id) : id(id) {};
+  DontMatchId(unsigned int id) : mId(id) {};
 
   bool operator() (XMLError e) const
   {
-    return e.getErrorId() != id;
+    return e.getErrorId() != mId;
   };
 
 private:
-  unsigned int id;
+  unsigned int mId;
 };
 
 /*
