@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -40,9 +40,7 @@
 #include <sbml/xml/XMLToken.h>
 
 /** @cond doxygenIgnored */
-
 using namespace std;
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_BEGIN
@@ -122,21 +120,14 @@ XMLToken::XMLToken (  const XMLTriple&    triple
  */
 XMLToken::XMLToken (  const std::string&  chars
                     , const unsigned int  line
-                    , const unsigned int  column ) :
-   mIsStart   ( false  )
+                    , const unsigned int  column ) 
+ : mChars     ( chars  )
+ , mIsStart   ( false  )
  , mIsEnd     ( false  )
  , mIsText    ( true   )
  , mLine      ( line   )
  , mColumn    ( column )
 {
-  if (&chars == NULL)
-  {
-    throw XMLConstructorException("NULL reference in XML constructor");
-  }
-  else
-  {
-    mChars = chars;
-  }
 }
 
 
@@ -152,37 +143,25 @@ XMLToken::~XMLToken ()
  * Copy constructor; creates a copy of this XMLToken.
  */
 XMLToken::XMLToken(const XMLToken& orig)
+ : mTriple()
+ , mAttributes()
+ , mNamespaces()
+ , mChars (orig.mChars)
+ , mIsStart (orig.mIsStart)
+ , mIsEnd (orig.mIsEnd)
+ , mIsText (orig.mIsText)
+ , mLine (orig.mLine)
+ , mColumn (orig.mColumn)
 {
-  if (&orig == NULL)
-  {
-    throw XMLConstructorException("Null argument to copy constructor");
-  }
-  else
-  {
-    if (orig.mTriple.isEmpty())
-      mTriple = XMLTriple();
-    else
-      mTriple = XMLTriple(orig.getName(), orig.getURI(), orig.getPrefix());
-    
-    if (orig.mAttributes.isEmpty())
-      mAttributes = XMLAttributes();
-    else
-      mAttributes = XMLAttributes(orig.getAttributes());
-    
-    if (orig.mNamespaces.isEmpty())
-      mNamespaces = XMLNamespaces();
-    else
-      mNamespaces = XMLNamespaces(orig.getNamespaces());
+  if (!orig.mTriple.isEmpty())
+    mTriple = XMLTriple(orig.getName(), orig.getURI(), orig.getPrefix());
+  
+  if (!orig.mAttributes.isEmpty())
+    mAttributes = XMLAttributes(orig.getAttributes());
+  
+  if (!orig.mNamespaces.isEmpty())
+    mNamespaces = XMLNamespaces(orig.getNamespaces());
 
-    mChars = orig.mChars;
-
-    mIsStart = orig.mIsStart;
-    mIsEnd = orig.mIsEnd;
-    mIsText = orig.mIsText;
-
-    mLine = orig.mLine;
-    mColumn = orig.mColumn;
-  }
 }
 
 
@@ -192,11 +171,7 @@ XMLToken::XMLToken(const XMLToken& orig)
 XMLToken& 
 XMLToken::operator=(const XMLToken& rhs)
 {
-  if (&rhs == NULL)
-  {
-    throw XMLConstructorException("Null argument to assignment operator");
-  }
-  else if(&rhs!=this)
+  if(&rhs!=this)
   {
     if (rhs.mTriple.isEmpty())
       mTriple = XMLTriple();
@@ -308,10 +283,6 @@ XMLToken::getAttributes () const
 int 
 XMLToken::setAttributes(const XMLAttributes& attributes)
 {
-	// test whether argument is valid
-	if(&attributes == NULL)
-		return LIBSBML_INVALID_OBJECT;
-
 
   /* the code will crash if the attributes points to NULL
    * put in a try catch statement to check
@@ -362,9 +333,9 @@ XMLToken::setAttributes(const XMLAttributes& attributes)
  */
 int 
 XMLToken::addAttr (  const std::string& name
-	           , const std::string& value
-    	           , const std::string& namespaceURI
-	           , const std::string& prefix      )
+                   , const std::string& value
+                   , const std::string& namespaceURI
+                   , const std::string& prefix      )
 {
   if (mIsStart) 
   {
@@ -779,9 +750,6 @@ XMLToken::getNamespaces () const
 int 
 XMLToken::setNamespaces(const XMLNamespaces& namespaces)
 {
-	// test whether argument is valid
-	if(&namespaces == NULL)
-		return LIBSBML_INVALID_OBJECT;
 
   /* the code will crash if the namespaces points to NULL
    * put in a try catch statement to check
@@ -815,7 +783,6 @@ XMLToken::setNamespaces(const XMLNamespaces& namespaces)
 int 
 XMLToken::addNamespace (const std::string& uri, const std::string& prefix)
 {
-  if (&uri == NULL || &prefix == NULL ) return LIBSBML_INVALID_OBJECT;
 
    if (mIsStart)  
    {
@@ -1054,9 +1021,6 @@ XMLToken::hasNamespaceNS(const std::string& uri, const std::string& prefix) cons
 int 
 XMLToken::setTriple(const XMLTriple& triple)
 {
-	// test whether argument is valid
-	if(&triple == NULL)
-		return LIBSBML_INVALID_OBJECT;
 
   /* the code will crash if the triple points to NULL
    * put in a try catch statement to check
@@ -1293,8 +1257,6 @@ operator<< (XMLOutputStream& stream, const XMLToken& token)
 
 #endif /* __cplusplus */
 /** @cond doxygenIgnored */
-
-
 LIBLAX_EXTERN
 XMLToken_t *
 XMLToken_create (void)
@@ -1933,8 +1895,6 @@ XMLToken_unsetEnd (XMLToken_t *token)
   if (token == NULL) return LIBSBML_INVALID_OBJECT;
   return token->unsetEnd();
 }
-
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_END
